# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_MARK_TEMPORAL_LOBE_METADATA = Metadata(
    id="a5a020bc6a51cd99fe31227a0a5e948147e247bf.boutiques",
    name="mri_mark_temporal_lobe",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriMarkTemporalLobeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_mark_temporal_lobe(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Marked temporal lobe output file"""


def mri_mark_temporal_lobe(
    subjects: list[InputPathType],
    output_file: str,
    spacing: str | None = None,
    use_gradient: bool = False,
    runner: Runner | None = None,
) -> MriMarkTemporalLobeOutputs:
    """
    A tool for marking the temporal lobe in MRI images.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjects: Subject MRI images.
        output_file: Output file for marked temporal lobes.
        spacing: The spacing of classifiers in canonical space.
        use_gradient: Flag to use intensity gradient as input to classifier.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriMarkTemporalLobeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_MARK_TEMPORAL_LOBE_METADATA)
    cargs = []
    cargs.append("mri_mark_temporal_lobe")
    if spacing is not None:
        cargs.extend([
            "-spacing",
            spacing
        ])
    if use_gradient:
        cargs.append("-gradient" + "".join([execution.input_file(f) for f in subjects]) + output_file)
    ret = MriMarkTemporalLobeOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_MARK_TEMPORAL_LOBE_METADATA",
    "MriMarkTemporalLobeOutputs",
    "mri_mark_temporal_lobe",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSREALPATH_METADATA = Metadata(
    id="ef28f86a2514a0354df33824818f45a5947ff878.boutiques",
    name="fsrealpath",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FsrealpathOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsrealpath(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fsrealpath(
    path: str,
    help_: bool = False,
    runner: Runner | None = None,
) -> FsrealpathOutputs:
    """
    Resolve symbolic links in a path.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        path: The path to resolve.
        help_: Show this help message and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsrealpathOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSREALPATH_METADATA)
    cargs = []
    cargs.append("fsrealpath")
    cargs.append(path)
    if help_:
        cargs.append("-h")
    ret = FsrealpathOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSREALPATH_METADATA",
    "FsrealpathOutputs",
    "fsrealpath",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_GRADIENT_INFO_METADATA = Metadata(
    id="31065ab477983c227eb79e13fe275d6a65852b07.boutiques",
    name="mri_gradient_info",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriGradientInfoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_gradient_info(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    gradient_info_output: OutputPathType
    """Text file containing the extracted gradient information."""


def mri_gradient_info(
    input_image: InputPathType,
    runner: Runner | None = None,
) -> MriGradientInfoOutputs:
    """
    A utility to obtain gradient information from MRI images using FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_image: Input MRI image file, typically in .mgz format.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriGradientInfoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_GRADIENT_INFO_METADATA)
    cargs = []
    cargs.append("mri_gradient_info")
    cargs.append(execution.input_file(input_image))
    ret = MriGradientInfoOutputs(
        root=execution.output_file("."),
        gradient_info_output=execution.output_file("gradient_info_output.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_GRADIENT_INFO_METADATA",
    "MriGradientInfoOutputs",
    "mri_gradient_info",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_QWARP_METADATA = Metadata(
    id="b31e14a7b7123e83340819abf222feefbe217a71.boutiques",
    name="3dQwarp",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dQwarpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_qwarp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    warped_dataset: OutputPathType
    """Warped dataset"""
    warp_dataset: OutputPathType
    """Warp dataset"""
    inverse_warp_dataset: OutputPathType
    """Inverse warp dataset"""


def v_3d_qwarp(
    base_dataset: InputPathType,
    source_dataset: InputPathType,
    prefix: str,
    no_warp: bool = False,
    inverse_warp: bool = False,
    no_dataset: bool = False,
    a_warp: bool = False,
    pcl: bool = False,
    pear: bool = False,
    hel: bool = False,
    mi: bool = False,
    nmi: bool = False,
    lpc: bool = False,
    lpa: bool = False,
    noneg: bool = False,
    nopenalty: bool = False,
    minpatch: float | None = None,
    maxlev: float | None = None,
    verbose: bool = False,
    quiet: bool = False,
    runner: Runner | None = None,
) -> V3dQwarpOutputs:
    """
    Computes a nonlinearly warped version of source_dataset to match base_dataset.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        base_dataset: Base dataset.
        source_dataset: Source dataset.
        prefix: Prefix for the output datasets.
        no_warp: Do not save the _WARP file.
        inverse_warp: Compute and save the _WARPINV file.
        no_dataset: Do not save the warped source dataset.
        a_warp: Output the nonlinear warp when -allineate is used.
        pcl: Clipped Pearson correlation (default method).
        pear: Use strict Pearson correlation for matching.
        hel: Use Hellinger metric for matching.
        mi: Use Mutual Information for matching.
        nmi: Use Normalized Mutual Information for matching.
        lpc: Use Local Pearson correlation (signed) for matching.
        lpa: Use Local Pearson correlation (absolute value) for matching.
        noneg: Replace negative values in either input volume with 0.
        nopenalty: Don't use a penalty on the cost functional.
        minpatch: Set the minimum patch size for warp searching.
        maxlev: Set the maximum refinement level.
        verbose: Print out very verbose progress messages.
        quiet: Cut out most progress messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dQwarpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_QWARP_METADATA)
    cargs = []
    cargs.append("3dQwarp")
    cargs.append(execution.input_file(base_dataset))
    cargs.append(execution.input_file(source_dataset))
    cargs.append(prefix)
    if no_warp:
        cargs.append("-nowarp")
    if inverse_warp:
        cargs.append("-iwarp")
    if no_dataset:
        cargs.append("-nodset")
    if a_warp:
        cargs.append("-awarp")
    if pcl:
        cargs.append("-pcl")
    if pear:
        cargs.append("-pear")
    if hel:
        cargs.append("-hel")
    if mi:
        cargs.append("-mi")
    if nmi:
        cargs.append("-nmi")
    if lpc:
        cargs.append("-lpc")
    if lpa:
        cargs.append("-lpa")
    if noneg:
        cargs.append("-noneg")
    if nopenalty:
        cargs.append("-nopenalty")
    if minpatch is not None:
        cargs.extend([
            "-minpatch",
            str(minpatch)
        ])
    if maxlev is not None:
        cargs.extend([
            "-maxlev",
            str(maxlev)
        ])
    if verbose:
        cargs.append("-verb")
    if quiet:
        cargs.append("-quiet")
    ret = V3dQwarpOutputs(
        root=execution.output_file("."),
        warped_dataset=execution.output_file("{PREFIX}+tlrc"),
        warp_dataset=execution.output_file("{PREFIX}_WARP+tlrc"),
        inverse_warp_dataset=execution.output_file("{PREFIX}_WARPINV+tlrc"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dQwarpOutputs",
    "V_3D_QWARP_METADATA",
    "v_3d_qwarp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TIMING_TOOL_PY_METADATA = Metadata(
    id="e72448a163610156059a44280593b8076536b24a.boutiques",
    name="timing_tool.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class TimingToolPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `timing_tool_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_timing_file: OutputPathType | None
    """Output timing file as specified"""
    timing_to_1_d_output: OutputPathType | None
    """Output 1D formatted stimulus data"""


def timing_tool_py(
    timing_file: InputPathType | None = None,
    output_file: str | None = None,
    run_length: list[float] | None = None,
    tr: float | None = None,
    offset: float | None = None,
    extend_file: InputPathType | None = None,
    sort: bool = False,
    scale_data: float | None = None,
    shift_to_run_offset: float | None = None,
    timing_to_1_d_file: str | None = None,
    stim_duration: float | None = None,
    multi_timing_files: list[InputPathType] | None = None,
    multi_show_isi_stats: bool = False,
    multi_show_timing: bool = False,
    show_timing: bool = False,
    multi_stim_duration: list[float] | None = None,
    round_times_frac: float | None = None,
    truncate_times: bool = False,
    multi_timing_event_list: str | None = None,
    runner: Runner | None = None,
) -> TimingToolPyOutputs:
    """
    Tool for manipulating and evaluating stimulus timing files.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        timing_file: Specify a stimulus timing file to load.
        output_file: Specify the output timing file.
        run_length: Specify the run duration(s), in seconds.
        tr: Specify the time resolution in 1D output (in seconds).
        offset: Add OFFSET to every time in the main element.
        extend_file: Extend timing rows with those in NEW_FILE.
        sort: Sort the times, per row (run).
        scale_data: Multiply every stim time by SCALAR.
        shift_to_run_offset: Shift times so first event is at start of run.
        timing_to_1_d_file: Convert stim_times format to stim_file.
        stim_duration: Specify the stimulus duration, in seconds.
        multi_timing_files: Specify multiple timing files to load.
        multi_show_isi_stats: Display timing and ISI statistics for the\
            multiple timing files.
        multi_show_timing: Display info on multiple timing elements.
        show_timing: Display info on the main timing element.
        multi_stim_duration: Specify stimulus duration(s), in seconds, for\
            multiple timing elements.
        round_times_frac: Round times to multiples of the TR (0.0 <= FRAC <=\
            1.0).
        truncate_times: Truncate times to multiples of the TR.
        multi_timing_event_list: Create an event list file from multiple timing\
            files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TimingToolPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TIMING_TOOL_PY_METADATA)
    cargs = []
    cargs.append("timing_tool.py")
    if timing_file is not None:
        cargs.extend([
            "-timing",
            execution.input_file(timing_file)
        ])
    if output_file is not None:
        cargs.extend([
            "-write_timing",
            output_file
        ])
    if run_length is not None:
        cargs.extend([
            "-run_len",
            *map(str, run_length)
        ])
    if tr is not None:
        cargs.extend([
            "-tr",
            str(tr)
        ])
    if offset is not None:
        cargs.extend([
            "-add_offset",
            str(offset)
        ])
    if extend_file is not None:
        cargs.extend([
            "-extend",
            execution.input_file(extend_file)
        ])
    if sort:
        cargs.append("-sort")
    if scale_data is not None:
        cargs.extend([
            "-scale_data",
            str(scale_data)
        ])
    if shift_to_run_offset is not None:
        cargs.extend([
            "-shift_to_run_offset",
            str(shift_to_run_offset)
        ])
    if timing_to_1_d_file is not None:
        cargs.extend([
            "-timing_to_1D",
            timing_to_1_d_file
        ])
    if stim_duration is not None:
        cargs.extend([
            "-stim_dur",
            str(stim_duration)
        ])
    if multi_timing_files is not None:
        cargs.extend([
            "-multi_timing",
            *[execution.input_file(f) for f in multi_timing_files]
        ])
    if multi_show_isi_stats:
        cargs.append("-multi_show_isi_stats")
    if multi_show_timing:
        cargs.append("-multi_show_timing_ele")
    if show_timing:
        cargs.append("-show_timing_ele")
    if multi_stim_duration is not None:
        cargs.extend([
            "-multi_stim_dur",
            *map(str, multi_stim_duration)
        ])
    if round_times_frac is not None:
        cargs.extend([
            "-round_times",
            str(round_times_frac)
        ])
    if truncate_times:
        cargs.append("-truncate_times")
    if multi_timing_event_list is not None:
        cargs.extend([
            "-multi_timing_to_event_list",
            multi_timing_event_list
        ])
    ret = TimingToolPyOutputs(
        root=execution.output_file("."),
        output_timing_file=execution.output_file(output_file) if (output_file is not None) else None,
        timing_to_1_d_output=execution.output_file(timing_to_1_d_file) if (timing_to_1_d_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TIMING_TOOL_PY_METADATA",
    "TimingToolPyOutputs",
    "timing_tool_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_EXTRACT_LABEL_METADATA = Metadata(
    id="0b9620a7206508bacb4685ef0d5ac119a68d3dd9.boutiques",
    name="mri_extract_label",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriExtractLabelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_extract_label(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume: OutputPathType
    """Extracted labeled voxels output volume."""


def mri_extract_label(
    input_volume: InputPathType,
    labels: list[str],
    output_name: str,
    gaussian_smoothing: float | None = None,
    transform_file: InputPathType | None = None,
    exit_none_found: bool = False,
    dilate: float | None = None,
    erode: float | None = None,
    runner: Runner | None = None,
) -> MriExtractLabelOutputs:
    """
    Extracts a set of labeled voxels from an image.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume from which to extract labels.
        labels: Labels to extract. Can include one or more labels.
        output_name: Name of the output file.
        gaussian_smoothing: Apply a Gaussian smoothing kernel with sigma.
        transform_file: Apply the transform in xform file to the extracted\
            volume.
        exit_none_found: Exit with error if none of the specified labels are\
            found.
        dilate: Dilate the output volume n times.
        erode: Erode the output volume n times.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriExtractLabelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_EXTRACT_LABEL_METADATA)
    cargs = []
    cargs.append("mri_extract_label")
    cargs.append(execution.input_file(input_volume))
    cargs.extend(labels)
    cargs.append(output_name)
    if gaussian_smoothing is not None:
        cargs.extend([
            "-s",
            str(gaussian_smoothing)
        ])
    if transform_file is not None:
        cargs.extend([
            "-t",
            execution.input_file(transform_file)
        ])
    if exit_none_found:
        cargs.append("-exit_none_found")
    if dilate is not None:
        cargs.extend([
            "-dilate",
            str(dilate)
        ])
    if erode is not None:
        cargs.extend([
            "-erode",
            str(erode)
        ])
    ret = MriExtractLabelOutputs(
        root=execution.output_file("."),
        output_volume=execution.output_file(output_name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_EXTRACT_LABEL_METADATA",
    "MriExtractLabelOutputs",
    "mri_extract_label",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RUN_SEGMENT_SUBJECT_SH_METADATA = Metadata(
    id="3bee4c6b7ffa07b5a4e27cd0261d6a71efb4387a.boutiques",
    name="run_SegmentSubject.sh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class RunSegmentSubjectShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `run_segment_subject_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """The generated output file from the segmentation process."""


def run_segment_subject_sh(
    deployed_mcrroot: str,
    arguments: str | None = None,
    runner: Runner | None = None,
) -> RunSegmentSubjectShOutputs:
    """
    A command-line tool for subject segmentation in Freesurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        deployed_mcrroot: The root directory of the deployed MATLAB Compiler\
            Runtime.
        arguments: Additional arguments to be passed to the SegmentSubject\
            script.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RunSegmentSubjectShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RUN_SEGMENT_SUBJECT_SH_METADATA)
    cargs = []
    cargs.append("run_SegmentSubject.sh")
    cargs.append(deployed_mcrroot)
    if arguments is not None:
        cargs.append(arguments)
    ret = RunSegmentSubjectShOutputs(
        root=execution.output_file("."),
        output=execution.output_file("outputFileName"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RUN_SEGMENT_SUBJECT_SH_METADATA",
    "RunSegmentSubjectShOutputs",
    "run_segment_subject_sh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_EXTRACT_FCD_FEATURES_METADATA = Metadata(
    id="4dc97ce09339ae602c500d2ce62f291dceb53709.boutiques",
    name="mri_extract_fcd_features",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriExtractFcdFeaturesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_extract_fcd_features(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_extract_fcd_features(
    subject: str,
    hemi: str,
    output_file: InputPathType,
    subjects_dir: str | None = None,
    runner: Runner | None = None,
) -> MriExtractFcdFeaturesOutputs:
    """
    A tool for extracting focal cortical dysplasia features.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: The subject identifier.
        hemi: The hemisphere (e.g., lh or rh).
        output_file: Output file path.
        subjects_dir: Specify SUBJECTS_DIR on the command line instead of in\
            the environment.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriExtractFcdFeaturesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_EXTRACT_FCD_FEATURES_METADATA)
    cargs = []
    cargs.append("mri_extract_fcd_features")
    cargs.append(subject)
    cargs.append(hemi)
    cargs.append(execution.input_file(output_file))
    if subjects_dir is not None:
        cargs.extend([
            "sdir",
            subjects_dir
        ])
    ret = MriExtractFcdFeaturesOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_EXTRACT_FCD_FEATURES_METADATA",
    "MriExtractFcdFeaturesOutputs",
    "mri_extract_fcd_features",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_MAKE_SURFACES_METADATA = Metadata(
    id="916ed4d56c0e1cd56b8963f58b7e229385c20cb5.boutiques",
    name="mris_make_surfaces",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisMakeSurfacesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_make_surfaces(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_make_surfaces(
    subject_name: str,
    hemisphere: str,
    white: str | None = None,
    pial: str | None = None,
    whiteonly: bool = False,
    nowhite: bool = False,
    orig_white: str | None = None,
    orig_pial: str | None = None,
    q: bool = False,
    max_gray_scale: float | None = None,
    c: bool = False,
    cortex: float | None = None,
    w: float | None = None,
    first_wm_peak: bool = False,
    a_avgs: float | None = None,
    pa_avgs: float | None = None,
    wa_avgs: float | None = None,
    t1_vol: str | None = None,
    w_vol: str | None = None,
    long: bool = False,
    dura_thresh: float | None = None,
    sdir: str | None = None,
    erase_cerebellum: bool = False,
    wm_weight: float | None = None,
    nsigma_above: float | None = None,
    nsigma_below: float | None = None,
    t2_min_inside: float | None = None,
    t2_max_inside: float | None = None,
    t2_outside_min: float | None = None,
    t2_outside_max: float | None = None,
    min_peak_pct: float | None = None,
    border_vals_hires: bool = False,
    no_unitize: bool = False,
    intensity: float | None = None,
    curv: float | None = None,
    tspring: float | None = None,
    nspring: float | None = None,
    repulse: float | None = None,
    save_target: bool = False,
    save_res: bool = False,
    v_vertexno: float | None = None,
    diag_vertex: float | None = None,
    rip: str | None = None,
    sigma_white: str | None = None,
    sigma_pial: str | None = None,
    output: str | None = None,
    min_border_white: float | None = None,
    max_border_white: float | None = None,
    min_gray_white_border: float | None = None,
    max_gray: float | None = None,
    max_gray_csf_border: float | None = None,
    min_gray_csf_border: float | None = None,
    max_csf: float | None = None,
    runner: Runner | None = None,
) -> MrisMakeSurfacesOutputs:
    """
    Positions the tessellation of the cortical surface at the white matter surface,
    then the gray matter surface, generating surface files along with a curvature
    file and a surface file for cortical thickness.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_name: Name of the subject.
        hemisphere: Brain hemisphere (r or l).
        white: Output name for white surface (default is 'white'). Set to\
            NOWHITE to generate but not save white surface.
        pial: Output name for pial surface (default is 'pial').
        whiteonly: Only generate white matter surface.
        nowhite: Only generate pial surface.
        orig_white: Specify a white surface to start with.
        orig_pial: Specify a pial surface to start with.
        q: Omit self-intersection and only generate gray/white surface.
        max_gray_scale: Set maximum gray scale value.
        c: Do not create curvature and area files from white matter surface.
        cortex: Set to 0 to turn off creation of cortex label file.
        w: Unused argument.
        first_wm_peak: Settle WM surface at first peak in intensity profile\
            instead of highest.
        a_avgs: Average curvature values a number of times (default=10).
        pa_avgs: Average pial curvature values a max of a number of times\
            (default=16).
        wa_avgs: Average white curvature values a max of a number of times\
            (default=4).
        t1_vol: Specify T1 volume (default is brain).
        w_vol: Specify white volume and <hires> option.
        long: Run longitudinal analysis.
        dura_thresh: Set a threshold for the multi-echo mprage dura avoidance.
        sdir: Specify SUBJECTS_DIR.
        erase_cerebellum: Erase cerebellar labeled voxels if aseg is loaded.
        wm_weight: Weighting of WM mean in calculating T2 threshold of\
            disallowed GM values, default=3.
        nsigma_above: # of sigmas above the mean to allow gray matter T2\
            intensities.
        nsigma_below: # of sigmas below the mean to allow gray matter T2\
            intensities.
        t2_min_inside: Specify threshold for min T2 value allowed to be\
            interior to the cortical ribbon.
        t2_max_inside: Specify threshold for max T2 value allowed to be\
            interior to the cortical ribbon.
        t2_outside_min: Specify threshold for min T2 value outside of pial\
            surface that will cause surface to deform outwards.
        t2_outside_max: Specify threshold for max T2 value outside of pial\
            surface that will cause surface to deform outwards.
        min_peak_pct: Specify the pct of the histo peak in the local gm\
            histogram to use as threshold for finding the local inside and outside\
            gm thresholds.
        border_vals_hires: Turn on hires options in\
            MRIScomputeBorderValues_new(). May not be helpful.
        no_unitize: Turn off face normal unitization.
        intensity: Set weight of intensity cost.
        curv: Set weight of curvature cost.
        tspring: Set weight of tangential spring cost.
        nspring: Set weight of normal spring cost.
        repulse: Set weight of repulsion force.
        save_target: Save target surface for debugging.
        save_res: Save residual for debugging.
        v_vertexno: Set Gdiag_no to vertex number.
        diag_vertex: Set Gdiag_no to vertex number and turn off writing of\
            cortex label or curvature files.
        rip: Save ripflag as overlay. Specify full path including hemi, suffix,\
            etc.
        sigma_white: Save white surface sigma as overlay. Specify full path\
            including hemi, suffix, etc.
        sigma_pial: Save pial surface sigma as overlay. Specify full path\
            including hemi, suffix, etc.
        output: Append suffix to all outputs to prevent over-writing.
        min_border_white: Minimum border white.
        max_border_white: Maximum border white.
        min_gray_white_border: Minimum gray at white border.
        max_gray: Maximum gray value.
        max_gray_csf_border: Maximum gray at CSF border.
        min_gray_csf_border: Minimum gray at CSF border.
        max_csf: Maximum CSF value.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisMakeSurfacesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_MAKE_SURFACES_METADATA)
    cargs = []
    cargs.append("mris_make_surfaces")
    cargs.append(subject_name)
    cargs.append(hemisphere)
    if white is not None:
        cargs.extend([
            "-white",
            white
        ])
    if pial is not None:
        cargs.extend([
            "-pial",
            pial
        ])
    if whiteonly:
        cargs.append("-whiteonly")
    if nowhite:
        cargs.append("-nowhite")
    if orig_white is not None:
        cargs.extend([
            "-orig_white",
            orig_white
        ])
    if orig_pial is not None:
        cargs.extend([
            "-orig_pial",
            orig_pial
        ])
    if q:
        cargs.append("-q")
    if max_gray_scale is not None:
        cargs.extend([
            "-max_gray_scale",
            str(max_gray_scale)
        ])
    if c:
        cargs.append("-c")
    if cortex is not None:
        cargs.extend([
            "-cortex",
            str(cortex)
        ])
    if w is not None:
        cargs.extend([
            "-w",
            str(w)
        ])
    if first_wm_peak:
        cargs.append("-first_wm_peak")
    if a_avgs is not None:
        cargs.extend([
            "-a",
            str(a_avgs)
        ])
    if pa_avgs is not None:
        cargs.extend([
            "-pa",
            str(pa_avgs)
        ])
    if wa_avgs is not None:
        cargs.extend([
            "-wa",
            str(wa_avgs)
        ])
    if t1_vol is not None:
        cargs.extend([
            "-T1",
            t1_vol
        ])
    if w_vol is not None:
        cargs.extend([
            "-wvol",
            w_vol
        ])
    if long:
        cargs.append("-long")
    if dura_thresh is not None:
        cargs.extend([
            "-dura_thresh",
            str(dura_thresh)
        ])
    if sdir is not None:
        cargs.extend([
            "-SDIR",
            sdir
        ])
    if erase_cerebellum:
        cargs.append("-erase_cerebellum")
    if wm_weight is not None:
        cargs.extend([
            "-wm_weight",
            str(wm_weight)
        ])
    if nsigma_above is not None:
        cargs.extend([
            "-nsigma_above",
            str(nsigma_above)
        ])
    if nsigma_below is not None:
        cargs.extend([
            "-nsigma_below",
            str(nsigma_below)
        ])
    if t2_min_inside is not None:
        cargs.extend([
            "-T2_min_inside",
            str(t2_min_inside)
        ])
    if t2_max_inside is not None:
        cargs.extend([
            "-T2_max_inside",
            str(t2_max_inside)
        ])
    if t2_outside_min is not None:
        cargs.extend([
            "-T2_outside_min",
            str(t2_outside_min)
        ])
    if t2_outside_max is not None:
        cargs.extend([
            "-T2_outside_max",
            str(t2_outside_max)
        ])
    if min_peak_pct is not None:
        cargs.extend([
            "-min_peak_pct",
            str(min_peak_pct)
        ])
    if border_vals_hires:
        cargs.append("-border-vals-hires")
    if no_unitize:
        cargs.append("-no-unitize")
    if intensity is not None:
        cargs.extend([
            "-intensity",
            str(intensity)
        ])
    if curv is not None:
        cargs.extend([
            "-curv",
            str(curv)
        ])
    if tspring is not None:
        cargs.extend([
            "-tspring",
            str(tspring)
        ])
    if nspring is not None:
        cargs.extend([
            "-nspring",
            str(nspring)
        ])
    if repulse is not None:
        cargs.extend([
            "-repulse",
            str(repulse)
        ])
    if save_target:
        cargs.append("-save-target")
    if save_res:
        cargs.append("-save-res")
    if v_vertexno is not None:
        cargs.extend([
            "-v",
            str(v_vertexno)
        ])
    if diag_vertex is not None:
        cargs.extend([
            "-diag-vertex",
            str(diag_vertex)
        ])
    if rip is not None:
        cargs.extend([
            "-rip",
            rip
        ])
    if sigma_white is not None:
        cargs.extend([
            "-sigma-white",
            sigma_white
        ])
    if sigma_pial is not None:
        cargs.extend([
            "-sigma-pial",
            sigma_pial
        ])
    if output is not None:
        cargs.extend([
            "-output",
            output
        ])
    if min_border_white is not None:
        cargs.extend([
            "-min_border_white",
            str(min_border_white)
        ])
    if max_border_white is not None:
        cargs.extend([
            "-max_border_white",
            str(max_border_white)
        ])
    if min_gray_white_border is not None:
        cargs.extend([
            "-min_gray_at_white_border",
            str(min_gray_white_border)
        ])
    if max_gray is not None:
        cargs.extend([
            "-max_gray",
            str(max_gray)
        ])
    if max_gray_csf_border is not None:
        cargs.extend([
            "-max_gray_at_csf_border",
            str(max_gray_csf_border)
        ])
    if min_gray_csf_border is not None:
        cargs.extend([
            "-min_gray_at_csf_border",
            str(min_gray_csf_border)
        ])
    if max_csf is not None:
        cargs.extend([
            "-max_csf",
            str(max_csf)
        ])
    ret = MrisMakeSurfacesOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_MAKE_SURFACES_METADATA",
    "MrisMakeSurfacesOutputs",
    "mris_make_surfaces",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RTVIEW_METADATA = Metadata(
    id="bbfc6a7778d4c734c212389406f89e8b0c6cbe09.boutiques",
    name="rtview",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class RtviewOutputs(typing.NamedTuple):
    """
    Output object returned when calling `rtview(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def rtview(
    subject: str | None = None,
    right_hemi: bool = False,
    polar: bool = False,
    real_file: InputPathType | None = None,
    imag_file: InputPathType | None = None,
    fsig_file: InputPathType | None = None,
    reg_file: InputPathType | None = None,
    flat_display: bool = False,
    patch: str | None = None,
    tcl_file: InputPathType | None = None,
    no_cleanup: bool = False,
    runner: Runner | None = None,
) -> RtviewOutputs:
    """
    View FSFAST version 5 retinotopy data using the color wheel. This is a front-end
    for tksurfer, setting up the environment for using the color wheel.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject to use as display.
        right_hemi: Display right hemisphere.
        polar: Display polar data.
        real_file: File containing real (cosine) values.
        imag_file: File containing imaginary (sine) values.
        fsig_file: File containing significance values.
        reg_file: Registration file for when real/imag/fsig are volumes.
        flat_display: Display on occip.patch.flat.
        patch: Display on specified patchname.
        tcl_file: Use your own TCL command file.
        no_cleanup: Don't delete temporary directory.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RtviewOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RTVIEW_METADATA)
    cargs = []
    cargs.append("rtview")
    if subject is not None:
        cargs.extend([
            "--s",
            subject
        ])
    if right_hemi:
        cargs.append("--rh")
    if polar:
        cargs.append("--polar")
    if real_file is not None:
        cargs.extend([
            "--real",
            execution.input_file(real_file)
        ])
    if imag_file is not None:
        cargs.extend([
            "--imag",
            execution.input_file(imag_file)
        ])
    if fsig_file is not None:
        cargs.extend([
            "--fsig",
            execution.input_file(fsig_file)
        ])
    if reg_file is not None:
        cargs.extend([
            "--reg",
            execution.input_file(reg_file)
        ])
    if flat_display:
        cargs.append("--flat")
    if patch is not None:
        cargs.extend([
            "--patch",
            patch
        ])
    if tcl_file is not None:
        cargs.extend([
            "--tcl",
            execution.input_file(tcl_file)
        ])
    if no_cleanup:
        cargs.append("--no-cleanup")
    ret = RtviewOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RTVIEW_METADATA",
    "RtviewOutputs",
    "rtview",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RUN_SEGMENT_SUBFIELDS_T1_LONGITUDINAL_SH_METADATA = Metadata(
    id="06a7bfba6231f999f1b4d6fa26f1a22c4fe4eb12.boutiques",
    name="run_SegmentSubfieldsT1Longitudinal.sh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class RunSegmentSubfieldsT1LongitudinalShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `run_segment_subfields_t1_longitudinal_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def run_segment_subfields_t1_longitudinal_sh(
    deployed_mcr_root: str,
    additional_args: str | None = None,
    runner: Runner | None = None,
) -> RunSegmentSubfieldsT1LongitudinalShOutputs:
    """
    Script for segmenting subfields from T1-weighted longitudinal data using
    FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        deployed_mcr_root: Root directory for the deployed MATLAB Runtime\
            environment.
        additional_args: Additional arguments for the script.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RunSegmentSubfieldsT1LongitudinalShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RUN_SEGMENT_SUBFIELDS_T1_LONGITUDINAL_SH_METADATA)
    cargs = []
    cargs.append("run_SegmentSubfieldsT1Longitudinal.sh")
    cargs.append(deployed_mcr_root)
    if additional_args is not None:
        cargs.append(additional_args)
    ret = RunSegmentSubfieldsT1LongitudinalShOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RUN_SEGMENT_SUBFIELDS_T1_LONGITUDINAL_SH_METADATA",
    "RunSegmentSubfieldsT1LongitudinalShOutputs",
    "run_segment_subfields_t1_longitudinal_sh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOLUME_STATS_METADATA = Metadata(
    id="18763776102c87c9e4124a22b788fb040dbe949b.boutiques",
    name="volume-stats",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class VolumeStatsRoi:
    """
    only consider data inside an roi.
    """
    roi_volume: InputPathType
    """the roi, as a volume file"""
    opt_match_maps: bool = False
    """each subvolume of input uses the corresponding subvolume from the roi
    file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-roi")
        cargs.append(execution.input_file(self.roi_volume))
        if self.opt_match_maps:
            cargs.append("-match-maps")
        return cargs


class VolumeStatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `volume_stats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def volume_stats(
    volume_in: InputPathType,
    opt_reduce_operation: str | None = None,
    opt_percentile_percent: float | None = None,
    opt_subvolume_subvolume: str | None = None,
    roi: VolumeStatsRoi | None = None,
    opt_show_map_name: bool = False,
    runner: Runner | None = None,
) -> VolumeStatsOutputs:
    """
    Spatial statistics on a volume file.
    
    For each subvolume of the input, a line of text is printed, resulting from
    the specified reduction or percentile operation. Use -subvolume to only give
    output for a single subvolume. If the -roi option is used without
    -match-maps, then each line will contain as many numbers as there are maps
    in the ROI file, separated by tab characters. Exactly one of -reduce or
    -percentile must be specified.
    
    The argument to the -reduce option must be one of the following:
    
    MAX: the maximum value
    MIN: the minimum value
    INDEXMAX: the 1-based index of the maximum value
    INDEXMIN: the 1-based index of the minimum value
    SUM: add all values
    PRODUCT: multiply all values
    MEAN: the mean of the data
    STDEV: the standard deviation (N denominator)
    SAMPSTDEV: the sample standard deviation (N-1 denominator)
    VARIANCE: the variance of the data
    TSNR: mean divided by sample standard deviation (N-1 denominator)
    COV: sample standard deviation (N-1 denominator) divided by mean
    L2NORM: square root of sum of squares
    MEDIAN: the median of the data
    MODE: the mode of the data
    COUNT_NONZERO: the number of nonzero elements in the data
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume_in: the input volume.
        opt_reduce_operation: use a reduction operation: the reduction\
            operation.
        opt_percentile_percent: give the value at a percentile: the percentile\
            to find, must be between 0 and 100.
        opt_subvolume_subvolume: only display output for one subvolume: the\
            subvolume number or name.
        roi: only consider data inside an roi.
        opt_show_map_name: print map index and name before each output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeStatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_STATS_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-stats")
    cargs.append(execution.input_file(volume_in))
    if opt_reduce_operation is not None:
        cargs.extend([
            "-reduce",
            opt_reduce_operation
        ])
    if opt_percentile_percent is not None:
        cargs.extend([
            "-percentile",
            str(opt_percentile_percent)
        ])
    if opt_subvolume_subvolume is not None:
        cargs.extend([
            "-subvolume",
            opt_subvolume_subvolume
        ])
    if roi is not None:
        cargs.extend(roi.run(execution))
    if opt_show_map_name:
        cargs.append("-show-map-name")
    ret = VolumeStatsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOLUME_STATS_METADATA",
    "VolumeStatsOutputs",
    "VolumeStatsRoi",
    "volume_stats",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_RF_LABEL_METADATA = Metadata(
    id="7f1e3e28634018fe4c2b21e53465fa3c07f2cb04.boutiques",
    name="mris_rf_label",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisRfLabelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_rf_label(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_rf_label(
    subject: str,
    rf_classifier: str,
    output_name: str,
    hemi: str | None = None,
    surf: str | None = None,
    runner: Runner | None = None,
) -> MrisRfLabelOutputs:
    """
    A tool for labeling regions of a surface using random forest classification.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject identifier.
        rf_classifier: Random Forest classifier.
        output_name: Output name.
        hemi: Process specified hemisphere instead of default (lh).
        surf: Change default surface name from 'white' to specified surface.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisRfLabelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_RF_LABEL_METADATA)
    cargs = []
    cargs.append("mris_rf_label")
    cargs.append(subject)
    cargs.append(rf_classifier)
    cargs.append(output_name)
    if hemi is not None:
        cargs.extend([
            "--hemi",
            hemi
        ])
    if surf is not None:
        cargs.extend([
            "--surf",
            surf
        ])
    ret = MrisRfLabelOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_RF_LABEL_METADATA",
    "MrisRfLabelOutputs",
    "mris_rf_label",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__ELECTRO_GRID_METADATA = Metadata(
    id="8d964e948445e43b1078948d73794b4d6f87e09a.boutiques",
    name="@ElectroGrid",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VElectroGridOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__electro_grid(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_surface: OutputPathType | None
    """Output surface file"""


def v__electro_grid(
    strip: int | None = None,
    grid: list[int] | None = None,
    prefix: str | None = None,
    coords: InputPathType | None = None,
    with_markers: bool = False,
    echo: bool = False,
    runner: Runner | None = None,
) -> VElectroGridOutputs:
    """
    Creates a mesh representation of an electrode grid for use with SUMA.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        strip: Make an Nx strip (array) of electrodes.
        grid: Make an Nx by Ny grid of electrodes. A node at (i,j) has a node\
            ID = i+Nx*j with 0<=i<Nx and 0<=j<=Ny.
        prefix: Use PREFIX for the output surface.
        coords: Specify the coordinates of the nodes on the grid, or the array.\
            XYZ.1D should have three columns, with each row specifying the\
            coordinates of one node.
        with_markers: Add markers to the surface at each electrode.
        echo: Set echo.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VElectroGridOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__ELECTRO_GRID_METADATA)
    cargs = []
    cargs.append("@ElectroGrid")
    if strip is not None:
        cargs.extend([
            "-strip",
            str(strip)
        ])
    if grid is not None:
        cargs.extend([
            "-grid",
            *map(str, grid)
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if coords is not None:
        cargs.extend([
            "-coords",
            execution.input_file(coords)
        ])
    if with_markers:
        cargs.append("-with_markers")
    if echo:
        cargs.append("-echo")
    ret = VElectroGridOutputs(
        root=execution.output_file("."),
        output_surface=execution.output_file(prefix + ".gii") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VElectroGridOutputs",
    "V__ELECTRO_GRID_METADATA",
    "v__electro_grid",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_MEF_SURFACES_METADATA = Metadata(
    id="02223303295326924a357b3a06e1f9463f061c83.boutiques",
    name="mris_mef_surfaces",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisMefSurfacesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_mef_surfaces(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_mef_surfaces(
    subject_name: str,
    hemisphere: str,
    omit_self_intersection: bool = False,
    curvature: bool = False,
    average_curvature: float | None = None,
    white_only: bool = False,
    runner: Runner | None = None,
) -> MrisMefSurfacesOutputs:
    """
    Positions the tessellation of the cortical surface at the white matter surface,
    then the gray matter surface and generates surface files for these surfaces.
    Also generates 'curvature' file for cortical thickness and a surface file
    approximating layer IV of the cortical sheet.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_name: Name of the subject.
        hemisphere: Hemisphere (e.g., left or right).
        omit_self_intersection: Omit self-intersection and only generate\
            gray/white surface.
        curvature: Create curvature and area files from the white matter\
            surface.
        average_curvature: Average curvature values specified number of times,\
            default is 10.
        white_only: Only generate the white matter surface.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisMefSurfacesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_MEF_SURFACES_METADATA)
    cargs = []
    cargs.append("mris_mef_surfaces")
    cargs.append(subject_name)
    cargs.append(hemisphere)
    if omit_self_intersection:
        cargs.append("-q")
    if curvature:
        cargs.append("-c")
    if average_curvature is not None:
        cargs.extend([
            "-a",
            str(average_curvature)
        ])
    if white_only:
        cargs.append("-whiteonly")
    ret = MrisMefSurfacesOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_MEF_SURFACES_METADATA",
    "MrisMefSurfacesOutputs",
    "mris_mef_surfaces",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TALAIRACH_MGH_METADATA = Metadata(
    id="470f9a508abcecfbd0c30650fa66adee5d4d661f.boutiques",
    name="talairach_mgh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class TalairachMghOutputs(typing.NamedTuple):
    """
    Output object returned when calling `talairach_mgh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    transformed_output: OutputPathType
    """Transformed output volume aligned with Talairach reference brain"""


def talairach_mgh(
    input_volume: InputPathType,
    output_volume: str,
    runner: Runner | None = None,
) -> TalairachMghOutputs:
    """
    A tool for aligning brain volume with Talairach reference brain.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume file for the talairach transformation.
        output_volume: Output volume file for the talairach transformation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TalairachMghOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TALAIRACH_MGH_METADATA)
    cargs = []
    cargs.append("talairach_mgh")
    cargs.append(execution.input_file(input_volume))
    cargs.append(output_volume)
    ret = TalairachMghOutputs(
        root=execution.output_file("."),
        transformed_output=execution.output_file(output_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TALAIRACH_MGH_METADATA",
    "TalairachMghOutputs",
    "talairach_mgh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTS_JOINT_LABEL_FUSION_SH_METADATA = Metadata(
    id="247a29d0e6dd59cbbad0a89af0ca5b7e052f7e73.boutiques",
    name="antsJointLabelFusion.sh",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AntsJointLabelFusionShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_joint_label_fusion_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    segmentation_output: OutputPathType | None
    """Output segmented image."""


def ants_joint_label_fusion_sh(
    target_image: str,
    mask_image: str,
    dimensionality: typing.Literal[2, 3] | None = None,
    output: str | None = None,
    atlas_image_mrf: str | None = None,
    atlas_segmentation_mrf: str | None = None,
    rigid_transform: str | None = None,
    similarity_metric: str | None = None,
    other_options: str | None = None,
    verbose: typing.Literal[0, 1] | None = None,
    rigid_transform_additional_options: str | None = None,
    similarity_metric_additional_options: str | None = None,
    runner: Runner | None = None,
) -> AntsJointLabelFusionShOutputs:
    """
    The antsJointLabelFusion script is used for performing label fusion using
    multiple atlases to improve segmentation accuracy.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        target_image: Image to segment.
        mask_image: Mask image.
        dimensionality: Image dimensionality (2 or 3).
        output: Root directory for the output segmentation.
        atlas_image_mrf: Atlas image(s) to be used for MRF initialization.
        atlas_segmentation_mrf: Atlas segmentation(s) to be used for MRF\
            initialization.
        rigid_transform: Rigid transform initialization.
        similarity_metric: Metric used for calculating similarity.
        other_options: Additional options for label fusion.
        verbose: Verbose output.
        rigid_transform_additional_options: Additional options for rigid\
            transform.
        similarity_metric_additional_options: Additional options for similarity\
            metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsJointLabelFusionShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_JOINT_LABEL_FUSION_SH_METADATA)
    cargs = []
    cargs.append("antsJointLabelFusion.sh")
    if dimensionality is not None:
        cargs.extend([
            "-d",
            str(dimensionality)
        ])
    if output is not None:
        cargs.extend([
            "-o",
            output
        ])
    if atlas_image_mrf is not None:
        cargs.extend([
            "-a",
            atlas_image_mrf
        ])
    if atlas_segmentation_mrf is not None:
        cargs.extend([
            "-l",
            atlas_segmentation_mrf
        ])
    if rigid_transform is not None:
        cargs.extend([
            "-g",
            rigid_transform
        ])
    if similarity_metric is not None:
        cargs.extend([
            "-s",
            similarity_metric
        ])
    if other_options is not None:
        cargs.extend([
            "-k",
            other_options
        ])
    if verbose is not None:
        cargs.extend([
            "-v",
            str(verbose)
        ])
    cargs.extend([
        "-i",
        target_image
    ])
    cargs.extend([
        "-m",
        mask_image
    ])
    if rigid_transform_additional_options is not None:
        cargs.extend([
            "-g",
            rigid_transform_additional_options
        ])
    if similarity_metric_additional_options is not None:
        cargs.extend([
            "-x",
            similarity_metric_additional_options
        ])
    ret = AntsJointLabelFusionShOutputs(
        root=execution.output_file("."),
        segmentation_output=execution.output_file(output + ".nii.gz") if (output is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTS_JOINT_LABEL_FUSION_SH_METADATA",
    "AntsJointLabelFusionShOutputs",
    "ants_joint_label_fusion_sh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_SEGCENTROIDS_METADATA = Metadata(
    id="60e55d3e62c17ddebe1721176cd1445c815b5c8c.boutiques",
    name="mri_segcentroids",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriSegcentroidsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_segcentroids(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_centroids: OutputPathType
    """Output text file containing the centroids."""


def mri_segcentroids(
    input_segmentation: InputPathType,
    output_file: str,
    pointset_flag: bool = False,
    registration_file: InputPathType | None = None,
    weights_file: InputPathType | None = None,
    lut_file: InputPathType | None = None,
    default_lut_flag: bool = False,
    runner: Runner | None = None,
) -> MriSegcentroidsOutputs:
    """
    Computes the center of mass for individual structures in a segmentation.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_segmentation: Input segmentation volume file.
        output_file: Output text file for centroids.
        pointset_flag: Save centroids as a Freeview pointset (json).
        registration_file: Apply a linear registration (lta).
        weights_file: Compute weighted centroids with provided voxel weights.
        lut_file: Specify label lookup table.
        default_lut_flag: Use default FreeSurferColorLUT.txt for lookup table.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriSegcentroidsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_SEGCENTROIDS_METADATA)
    cargs = []
    cargs.append("mri_segcentroids")
    cargs.extend([
        "--i",
        execution.input_file(input_segmentation)
    ])
    cargs.extend([
        "--o",
        output_file
    ])
    if pointset_flag:
        cargs.append("--p")
    if registration_file is not None:
        cargs.extend([
            "--reg",
            execution.input_file(registration_file)
        ])
    if weights_file is not None:
        cargs.extend([
            "--weights",
            execution.input_file(weights_file)
        ])
    if lut_file is not None:
        cargs.extend([
            "--ctab",
            execution.input_file(lut_file)
        ])
    if default_lut_flag:
        cargs.append("--ctab-default")
    ret = MriSegcentroidsOutputs(
        root=execution.output_file("."),
        output_centroids=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_SEGCENTROIDS_METADATA",
    "MriSegcentroidsOutputs",
    "mri_segcentroids",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SIENAX_METADATA = Metadata(
    id="24815e75293ede1a0cd5e50db5d38a8535b21678.boutiques",
    name="sienax",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class SienaxOutputs(typing.NamedTuple):
    """
    Output object returned when calling `sienax(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    segmentation_output: OutputPathType | None
    """Segmentation output file"""
    report_output: OutputPathType | None
    """Summary report file"""


def sienax(
    infile: InputPathType,
    output_dir: str | None = None,
    debug_flag: bool = False,
    bet_options: str | None = None,
    twoclass_segment_flag: bool = False,
    t2_flag: bool = False,
    top_threshold: float | None = None,
    bottom_threshold: float | None = None,
    regional_flag: bool = False,
    lesion_mask: InputPathType | None = None,
    fast_options: str | None = None,
    runner: Runner | None = None,
) -> SienaxOutputs:
    """
    A tool to estimate brain tissue volume from a single MR image and to compare it
    to an external standard.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        infile: Input image (e.g. img.nii.gz).
        output_dir: Output directory (default output is <input>_sienax).
        debug_flag: Debug (don't delete intermediate files).
        bet_options: Options to pass to BET brain extraction (inside\
            double-quotes), e.g. -B "-f 0.3".
        twoclass_segment_flag: Two-class segmentation (don't segment grey and\
            white matter separately).
        t2_flag: Input image is T2-weighted (default is T1-weighted).
        top_threshold: Ignore from t (mm) upwards in MNI152/Talairach space.
        bottom_threshold: Ignore from b (mm) downwards in MNI152/Talairach\
            space (b should probably be negative).
        regional_flag: Regional - use standard-space masks to give peripheral\
            cortex GM volume (3-class segmentation only) and ventricular CSF volume.
        lesion_mask: Use lesion (or lesion+CSF) mask to remove incorrectly\
            labelled 'grey matter' voxels.
        fast_options: Options to pass to FAST segmentation (inside\
            double-quotes), e.g. -S "I 20".
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SienaxOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SIENAX_METADATA)
    cargs = []
    cargs.append("sienax")
    cargs.append(execution.input_file(infile))
    if output_dir is not None:
        cargs.extend([
            "-o",
            output_dir
        ])
    if debug_flag:
        cargs.append("-d")
    if bet_options is not None:
        cargs.extend([
            "-B",
            bet_options
        ])
    if twoclass_segment_flag:
        cargs.append("-2")
    if t2_flag:
        cargs.append("-t2")
    if top_threshold is not None:
        cargs.extend([
            "-t",
            str(top_threshold)
        ])
    if bottom_threshold is not None:
        cargs.extend([
            "-b",
            str(bottom_threshold)
        ])
    if regional_flag:
        cargs.append("-r")
    if lesion_mask is not None:
        cargs.extend([
            "-lm",
            execution.input_file(lesion_mask)
        ])
    if fast_options is not None:
        cargs.extend([
            "-S",
            fast_options
        ])
    ret = SienaxOutputs(
        root=execution.output_file("."),
        segmentation_output=execution.output_file(output_dir + "/segmentation.nii.gz") if (output_dir is not None) else None,
        report_output=execution.output_file(output_dir + "/report.txt") if (output_dir is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SIENAX_METADATA",
    "SienaxOutputs",
    "sienax",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_DTTO_NOISY_DWI_METADATA = Metadata(
    id="0ef5fe03a8b952b27e737adb59a395ac94790601.boutiques",
    name="3dDTtoNoisyDWI",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dDttoNoisyDwiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_dtto_noisy_dwi(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dwi: OutputPathType
    """Synthetic set of DWI measures with noise. Contains N+1 bricks mimicking
    B0+DWI data."""


def v_3d_dtto_noisy_dwi(
    dt_file: InputPathType,
    grad_file: InputPathType,
    noise_dwi: float,
    prefix: str,
    noise_b0: float | None = None,
    mask: InputPathType | None = None,
    bval: float | None = None,
    s0: float | None = None,
    runner: Runner | None = None,
) -> V3dDttoNoisyDwiOutputs:
    """
    Generate a synthetic set of DWI measures with a given SNR from an AFNI-style DT
    file and a set of gradients. This can be useful for simulations and testing.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dt_file: Diffusion tensor file with six bricks of DT components ordered\
            in the AFNI manner: Dxx,Dxy,Dyy,Dxz,Dyz,Dzz.
        grad_file: Text file of gradients arranged in three columns. There\
            should be no row of all zeros representing the b=0 line.
        noise_dwi: Fractional value of noise in DWIs. FF = sigma/S0 = 1/SNR0.\
            For example, FF=0.05 corresponds to SNR0=20.
        prefix: Output file name prefix. Will have N+1 bricks when GRADFILE has\
            N rows of gradients.
        noise_b0: Optional fraction of Rician noise in the b=0 reference image.\
            If not provided, FF2=FF.
        mask: Optional mask within which to calculate uncertainty. Data should\
            be masked already otherwise.
        bval: Optional DW factor to use if DT values are scaled to something\
            physical. Default is BB=1.
        s0: Optional reference b=0 signal strength. Default value is SS=1000.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dDttoNoisyDwiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_DTTO_NOISY_DWI_METADATA)
    cargs = []
    cargs.append("3dDTtoNoisyDWI")
    cargs.append(execution.input_file(dt_file))
    cargs.append(execution.input_file(grad_file))
    cargs.extend([
        "-noise_DWI",
        str(noise_dwi)
    ])
    if noise_b0 is not None:
        cargs.extend([
            "-noise_B0",
            str(noise_b0)
        ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if bval is not None:
        cargs.extend([
            "-bval",
            str(bval)
        ])
    if s0 is not None:
        cargs.extend([
            "-S0",
            str(s0)
        ])
    ret = V3dDttoNoisyDwiOutputs(
        root=execution.output_file("."),
        output_dwi=execution.output_file(prefix + "+orig"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dDttoNoisyDwiOutputs",
    "V_3D_DTTO_NOISY_DWI_METADATA",
    "v_3d_dtto_noisy_dwi",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__SHOW_DYNAMIC_RANGE_METADATA = Metadata(
    id="d0ec3925ed417e46aad2070bdc6ba2ddd1248eca.boutiques",
    name="@ShowDynamicRange",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VShowDynamicRangeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__show_dynamic_range(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    minpercchange_file: OutputPathType
    """Dataset showing the percent signal change that an increment of 1
    digitized value in the time series corresponds to."""
    range_file: OutputPathType
    """Dataset showing the number of discrete levels used to represent the time
    series."""


def v__show_dynamic_range(
    infile: InputPathType,
    runner: Runner | None = None,
) -> VShowDynamicRangeOutputs:
    """
    The script checks the dynamic range of the time series data at locations inside
    the brain.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        infile: Input EPI time series dataset (e.g. epi.nii.gz).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VShowDynamicRangeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__SHOW_DYNAMIC_RANGE_METADATA)
    cargs = []
    cargs.append("@ShowDynamicRange")
    cargs.append(execution.input_file(infile))
    ret = VShowDynamicRangeOutputs(
        root=execution.output_file("."),
        minpercchange_file=execution.output_file(pathlib.Path(infile).name + "_minpercchange.nii.gz"),
        range_file=execution.output_file(pathlib.Path(infile).name + ".range.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VShowDynamicRangeOutputs",
    "V__SHOW_DYNAMIC_RANGE_METADATA",
    "v__show_dynamic_range",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIRST_FLIRT_METADATA = Metadata(
    id="84256599d7a1450603ccdb556a18e0725b6d55be.boutiques",
    name="first_flirt",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FirstFlirtOutputs(typing.NamedTuple):
    """
    Output object returned when calling `first_flirt(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    registered_output_image: OutputPathType
    """Output image registered to standard space"""
    log_file: OutputPathType
    """Log file containing details of the registration process"""
    transformation_matrix: OutputPathType
    """Transformation matrix file"""


def first_flirt(
    input_image: InputPathType,
    output_basename: str,
    already_brain_extracted_flag: bool = False,
    debug_flag: bool = False,
    inweight_flag: bool = False,
    strucweight_mask: InputPathType | None = None,
    cort_flag: bool = False,
    cost_function: str | None = None,
    runner: Runner | None = None,
) -> FirstFlirtOutputs:
    """
    FLIRT-based image registration tool with additional options for brain extraction
    and weighting masks.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_image: Input image (e.g. subject10rawT1.nii.gz).
        output_basename: Output basename for the results (e.g.\
            subject10rawT1_to_std_sub).
        already_brain_extracted_flag: Input is already brain extracted.
        debug_flag: Debug mode: don't delete intermediate files.
        inweight_flag: Use a weighting mask on the first registration.
        strucweight_mask: Use a specific structure weighting mask (in standard\
            space) for an optional third-stage registration step (e.g.\
            maskimage.nii.gz).
        cort_flag: Use a weighting mask of the whole brain on the first\
            registration for specific models.
        cost_function: Specify the cost function to be used by all FLIRT calls.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FirstFlirtOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIRST_FLIRT_METADATA)
    cargs = []
    cargs.append("first_flirt")
    cargs.append(execution.input_file(input_image))
    cargs.append(output_basename)
    if already_brain_extracted_flag:
        cargs.append("-b")
    if debug_flag:
        cargs.append("-d")
    if inweight_flag:
        cargs.append("-inweight")
    if strucweight_mask is not None:
        cargs.extend([
            "-strucweight",
            execution.input_file(strucweight_mask)
        ])
    if cort_flag:
        cargs.append("-cort")
    if cost_function is not None:
        cargs.extend([
            "-cost",
            cost_function
        ])
    ret = FirstFlirtOutputs(
        root=execution.output_file("."),
        registered_output_image=execution.output_file(output_basename + "_result.nii.gz"),
        log_file=execution.output_file(output_basename + "_log.txt"),
        transformation_matrix=execution.output_file(output_basename + "_matrix.mat"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIRST_FLIRT_METADATA",
    "FirstFlirtOutputs",
    "first_flirt",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_BLUR_IN_MASK_METADATA = Metadata(
    id="2020eccbab2609356d0e3ab2fdd84a54c25cb900.boutiques",
    name="3dBlurInMask",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dBlurInMaskOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_blur_in_mask(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output dataset"""


def v_3d_blur_in_mask(
    input_file: InputPathType,
    output_prefix: str,
    fwhm: float,
    fwhm_dataset: InputPathType | None = None,
    mask: InputPathType | None = None,
    multi_mask: InputPathType | None = None,
    automask: bool = False,
    preserve: bool = False,
    quiet: bool = False,
    float_: bool = False,
    fwhm_xyz: list[float] | None = None,
    runner: Runner | None = None,
) -> V3dBlurInMaskOutputs:
    """
    Blurs a dataset spatially inside a mask.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_file: Dataset to be smoothed and output.
        output_prefix: Prefix for output dataset.
        fwhm: Amount of smoothness to add to the dataset (in mm).
        fwhm_dataset: Dataset containing the amount of smoothness for each\
            voxel.
        mask: Mask dataset for blurring; voxels NOT in the mask will be zeroed\
            in the output.
        multi_mask: Multi-mask dataset; each distinct nonzero value is treated\
            as a separate mask.
        automask: Create an automask from the input dataset.
        preserve: Preserve original values in the dataset outside the mask.
        quiet: Don't be verbose with progress reports.
        float_: Save dataset as floats.
        fwhm_xyz: Add different amounts of smoothness in the 3 spatial\
            directions.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dBlurInMaskOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_BLUR_IN_MASK_METADATA)
    cargs = []
    cargs.append("3dBlurInMask")
    cargs.append(execution.input_file(input_file))
    cargs.append(output_prefix)
    cargs.extend([
        "-FWHM",
        str(fwhm)
    ])
    if fwhm_dataset is not None:
        cargs.extend([
            "-FWHMdset",
            execution.input_file(fwhm_dataset)
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if multi_mask is not None:
        cargs.extend([
            "-Mmask",
            execution.input_file(multi_mask)
        ])
    if automask:
        cargs.append("-automask")
    if preserve:
        cargs.append("-preserve")
    if quiet:
        cargs.append("-quiet")
    if float_:
        cargs.append("-float")
    if fwhm_xyz is not None:
        cargs.extend([
            "-FWHMxyz",
            *map(str, fwhm_xyz)
        ])
    ret = V3dBlurInMaskOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_prefix),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dBlurInMaskOutputs",
    "V_3D_BLUR_IN_MASK_METADATA",
    "v_3d_blur_in_mask",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MAKE_SEGVOL_TABLE_METADATA = Metadata(
    id="584e18cf5964aa90ad96025eab578f07dcec865b.boutiques",
    name="make-segvol-table",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MakeSegvolTableOutputs(typing.NamedTuple):
    """
    Output object returned when calling `make_segvol_table(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_table: OutputPathType
    """Output text file containing the table of subcortical structure
    volumes."""


def make_segvol_table(
    subjects: list[str],
    subject_file: InputPathType,
    outfile: str,
    idmap: InputPathType | None = None,
    structure_ids: list[str] | None = None,
    segdir: str | None = None,
    subjects_dir: str | None = None,
    umask: str | None = None,
    version: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> MakeSegvolTableOutputs:
    """
    Creates a table of volumes of subcortical structures for a given list of
    subjects using FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjects: List of subject IDs. Each subject should be specified with a\
            separate -s flag.
        subject_file: Path to a file containing a list of subjects.
        outfile: Output file where the table will be saved.
        idmap: File with structure name and id number. Default is\
            FREESURFER_HOME/tkmeditColorsCMA.
        structure_ids: Names of structures to include in the table. Defaults to\
            all structures.
        segdir: Segmentation subdirectory name. Default is 'aseg'.
        subjects_dir: Path to the subjects directory. Default is SUBJECTS_DIR\
            environment variable.
        umask: Set UNIX file permission mask.
        version: Print version and exit.
        help_: Display help information.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MakeSegvolTableOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAKE_SEGVOL_TABLE_METADATA)
    cargs = []
    cargs.append("make-segvol-table")
    cargs.extend([
        "-s",
        *subjects
    ])
    cargs.extend([
        "-sf",
        execution.input_file(subject_file)
    ])
    cargs.extend([
        "-o",
        outfile
    ])
    if idmap is not None:
        cargs.extend([
            "-idmap",
            execution.input_file(idmap)
        ])
    if structure_ids is not None:
        cargs.extend([
            "-id",
            *structure_ids
        ])
    if segdir is not None:
        cargs.extend([
            "-segdir",
            segdir
        ])
    if subjects_dir is not None:
        cargs.extend([
            "-sd",
            subjects_dir
        ])
    if umask is not None:
        cargs.extend([
            "-umask",
            umask
        ])
    if version:
        cargs.append("-version")
    if help_:
        cargs.append("-help")
    ret = MakeSegvolTableOutputs(
        root=execution.output_file("."),
        output_table=execution.output_file(outfile),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MAKE_SEGVOL_TABLE_METADATA",
    "MakeSegvolTableOutputs",
    "make_segvol_table",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DSVM_LINPREDICT_METADATA = Metadata(
    id="162a26d7cd1e95514fe2260fa414829582d88bd4.boutiques",
    name="3dsvm_linpredict",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dsvmLinpredictOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dsvm_linpredict(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    stdout_output: OutputPathType
    """The result is a number printed to stdout"""


def v_3dsvm_linpredict(
    weight_vector: InputPathType,
    input_dataset: str,
    mask_dataset: InputPathType | None = None,
    runner: Runner | None = None,
) -> V3dsvmLinpredictOutputs:
    """
    Linear prediction for weights from 3dsvm.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        weight_vector: Weight vector dataset.
        input_dataset: Input dataset, potentially with sub-brick and/or\
            sub-range selectors.
        mask_dataset: Dataset to be used as a mask. Only voxels with nonzero\
            values in 'mset' will be averaged from 'dataset'. The mask dataset and\
            the input dataset must have the same number of voxels.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dsvmLinpredictOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DSVM_LINPREDICT_METADATA)
    cargs = []
    cargs.append("3dsvm_linpredict")
    if mask_dataset is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask_dataset)
        ])
    cargs.append(execution.input_file(weight_vector))
    cargs.append(input_dataset)
    ret = V3dsvmLinpredictOutputs(
        root=execution.output_file("."),
        stdout_output=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dsvmLinpredictOutputs",
    "V_3DSVM_LINPREDICT_METADATA",
    "v_3dsvm_linpredict",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_SURFCLUSTER_METADATA = Metadata(
    id="d511292684dbbb10f74daadd0e2a8026a7360392.boutiques",
    name="mri_surfcluster",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriSurfclusterOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_surfcluster(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_surface_file: OutputPathType | None
    """Filtered surface file with non-cluster vertices set to 0"""
    output_cluster_number_file: OutputPathType | None
    """Surface file with cluster number per vertex"""
    output_labels: OutputPathType | None
    """Label files for clusters"""
    output_summary_file: OutputPathType | None
    """Text summary file of clustering results"""
    output_pointset_file: OutputPathType | None
    """Pointset file for visualization in Freeview"""
    output_max_area_file: OutputPathType | None
    """File containing the area of the largest cluster"""


def mri_surfcluster(
    infile: InputPathType,
    thmin: float | None = None,
    sign: str | None = None,
    no_adjust_flag: bool = False,
    fdr: float | None = None,
    subject: str | None = None,
    hemi: str | None = None,
    surf: str | None = None,
    surfpath: str | None = None,
    annot: str | None = None,
    frame: float | None = None,
    csd: list[InputPathType] | None = None,
    vwsig: str | None = None,
    cwsig: str | None = None,
    maxcwpval: str | None = None,
    bonferroni: float | None = None,
    sig2p_max_flag: bool = False,
    bonferroni_max: float | None = None,
    csdpdf: str | None = None,
    csdpdf_only_flag: bool = False,
    csd_out: InputPathType | None = None,
    cwpvalthresh: float | None = None,
    fwhm: float | None = None,
    fwhmdat: str | None = None,
    clabel: InputPathType | None = None,
    cortex_flag: bool = False,
    mask: InputPathType | None = None,
    mask_inv_flag: bool = False,
    centroid_flag: bool = False,
    sum_: InputPathType | None = None,
    pointset: InputPathType | None = None,
    maxareafile: str | None = None,
    o: str | None = None,
    ocn: str | None = None,
    olab: str | None = None,
    oannot: str | None = None,
    minarea: float | None = None,
    xfm: InputPathType | None = None,
    no_fixmni_flag: bool = False,
    sd: str | None = None,
    thmax: float | None = None,
    runner: Runner | None = None,
) -> MriSurfclusterOutputs:
    """
    A tool for clustering vertices on a cortical surface based on intensity values.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        infile: Source of surface values.
        thmin: Minimum intensity threshold.
        sign: Sign of threshold criteria (abs, pos, neg).
        no_adjust_flag: Do not adjust threshold for one-tailed tests.
        fdr: Set thmin with False Discovery Rate.
        subject: Source surface subject (can be ico).
        hemi: Cortical hemisphere, either lh or rh.
        surf: Coordinates from surface (e.g., white).
        surfpath: Full path to surface.
        annot: Report annotation for max vertex (e.g., aparc).
        frame: 0-based frame number of the input file.
        csd: Load one or more CSD files.
        vwsig: Map of corrected voxel-wise significances.
        cwsig: Map of cluster-wise significances.
        maxcwpval: Save p-value of the largest (max) cluster.
        bonferroni: Apply Bonferroni correction across N spaces.
        sig2p_max_flag: Convert max from sig to p.
        bonferroni_max: Apply Bonferroni correction to maximum.
        csdpdf: Compute PDF/CDF of CSD data and save.
        csdpdf_only_flag: Only write the CSD PDF file.
        csd_out: Write out merged CSD files as one.
        cwpvalthresh: Cluster-wise threshold.
        fwhm: FWHM in mm^2 for GRF.
        fwhmdat: Text file with FWHM in mm^2 for GRF.
        clabel: Constrain cluster search to be inside or outside clabel.
        cortex_flag: Set clabel to be subject/label/hemi.cortex.label.
        mask: Constrain to be within mask.
        mask_inv_flag: Constrain cluster search to be outside mask or clabel.
        centroid_flag: Report centroid instead of location of maximum stat.
        sum_: Text file to store cluster summary.
        pointset: File that can be read into Freeview with -c.
        maxareafile: Write area of largest cluster to this file.
        o: Output file with non-clusters set to 0.
        ocn: Output file where value is cluster number.
        olab: Output clusters as labels.
        oannot: Output clusters as an annotation.
        minarea: Area threshold for a cluster (mm^2).
        xfm: Talairach transform file.
        no_fixmni_flag: Do not fix MNI Talairach coordinates.
        sd: FreeSurfer subjects directory.
        thmax: Maximum intensity threshold.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriSurfclusterOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_SURFCLUSTER_METADATA)
    cargs = []
    cargs.append("mri_surfcluster")
    cargs.extend([
        "--in",
        execution.input_file(infile)
    ])
    if thmin is not None:
        cargs.extend([
            "--thmin",
            str(thmin)
        ])
    if sign is not None:
        cargs.extend([
            "--sign",
            sign
        ])
    if no_adjust_flag:
        cargs.append("--no-adjust")
    if fdr is not None:
        cargs.extend([
            "--fdr",
            str(fdr)
        ])
    if subject is not None:
        cargs.extend([
            "--subject",
            subject
        ])
    if hemi is not None:
        cargs.extend([
            "--hemi",
            hemi
        ])
    if surf is not None:
        cargs.extend([
            "--surf",
            surf
        ])
    if surfpath is not None:
        cargs.extend([
            "--surfpath",
            surfpath
        ])
    if annot is not None:
        cargs.extend([
            "--annot",
            annot
        ])
    if frame is not None:
        cargs.extend([
            "--frame",
            str(frame)
        ])
    if csd is not None:
        cargs.extend([
            "--csd",
            *[execution.input_file(f) for f in csd]
        ])
    if vwsig is not None:
        cargs.extend([
            "--vwsig",
            vwsig
        ])
    if cwsig is not None:
        cargs.extend([
            "--cwsig",
            cwsig
        ])
    if maxcwpval is not None:
        cargs.extend([
            "--maxcwpval",
            maxcwpval
        ])
    if bonferroni is not None:
        cargs.extend([
            "--bonferroni",
            str(bonferroni)
        ])
    if sig2p_max_flag:
        cargs.append("--sig2p-max")
    if bonferroni_max is not None:
        cargs.extend([
            "--bonferroni-max",
            str(bonferroni_max)
        ])
    if csdpdf is not None:
        cargs.extend([
            "--csdpdf",
            csdpdf
        ])
    if csdpdf_only_flag:
        cargs.append("--csdpdf-only")
    if csd_out is not None:
        cargs.extend([
            "--csd-out",
            execution.input_file(csd_out)
        ])
    if cwpvalthresh is not None:
        cargs.extend([
            "--cwpvalthresh",
            str(cwpvalthresh)
        ])
    if fwhm is not None:
        cargs.extend([
            "--fwhm",
            str(fwhm)
        ])
    if fwhmdat is not None:
        cargs.extend([
            "--fwhmdat",
            fwhmdat
        ])
    if clabel is not None:
        cargs.extend([
            "--clabel",
            execution.input_file(clabel)
        ])
    if cortex_flag:
        cargs.append("--cortex")
    if mask is not None:
        cargs.extend([
            "--mask",
            execution.input_file(mask)
        ])
    if mask_inv_flag:
        cargs.append("--mask-inv")
    if centroid_flag:
        cargs.append("--centroid")
    if sum_ is not None:
        cargs.extend([
            "--sum",
            execution.input_file(sum_)
        ])
    if pointset is not None:
        cargs.extend([
            "--pointset",
            execution.input_file(pointset)
        ])
    if maxareafile is not None:
        cargs.extend([
            "--maxareafile",
            maxareafile
        ])
    if o is not None:
        cargs.extend([
            "--o",
            o
        ])
    if ocn is not None:
        cargs.extend([
            "--ocn",
            ocn
        ])
    if olab is not None:
        cargs.extend([
            "--olab",
            olab
        ])
    if oannot is not None:
        cargs.extend([
            "--oannot",
            oannot
        ])
    if minarea is not None:
        cargs.extend([
            "--minarea",
            str(minarea)
        ])
    if xfm is not None:
        cargs.extend([
            "--xfm",
            execution.input_file(xfm)
        ])
    if no_fixmni_flag:
        cargs.append("--nofixmni")
    if sd is not None:
        cargs.extend([
            "--sd",
            sd
        ])
    if thmax is not None:
        cargs.extend([
            "--thmax",
            str(thmax)
        ])
    ret = MriSurfclusterOutputs(
        root=execution.output_file("."),
        output_surface_file=execution.output_file(o) if (o is not None) else None,
        output_cluster_number_file=execution.output_file(ocn) if (ocn is not None) else None,
        output_labels=execution.output_file(olab + "-*.label") if (olab is not None) else None,
        output_summary_file=execution.output_file(pathlib.Path(sum_).name) if (sum_ is not None) else None,
        output_pointset_file=execution.output_file(pathlib.Path(pointset).name) if (pointset is not None) else None,
        output_max_area_file=execution.output_file(maxareafile) if (maxareafile is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_SURFCLUSTER_METADATA",
    "MriSurfclusterOutputs",
    "mri_surfcluster",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_MAP_CUTS_METADATA = Metadata(
    id="779b9e3d194c64fbf7ebe1bfe928f56ccdd44441.boutiques",
    name="mris_map_cuts",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisMapCutsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_map_cuts(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_map_cuts(
    input_patch: InputPathType,
    output_patch: str,
    runner: Runner | None = None,
) -> MrisMapCutsOutputs:
    """
    Tool for mapping cortical surface data onto cuts.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_patch: Input patch file.
        output_patch: Output patch file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisMapCutsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_MAP_CUTS_METADATA)
    cargs = []
    cargs.append("mris_map_cuts")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(input_patch))
    cargs.append(output_patch)
    ret = MrisMapCutsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_MAP_CUTS_METADATA",
    "MrisMapCutsOutputs",
    "mris_map_cuts",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_CA_TRAIN_METADATA = Metadata(
    id="8e70a6159e0a5ec42aaae4b7bcd8282432b8dd18.boutiques",
    name="mris_ca_train",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisCaTrainOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_ca_train(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Classifier array output file generated by mris_ca_train"""


def mris_ca_train(
    hemi: str,
    canonsurf: InputPathType,
    annot_file: InputPathType,
    subjects: list[str],
    output_file: str,
    sdir: str | None = None,
    nbrs: float | None = None,
    orig: InputPathType | None = None,
    norm1: bool = False,
    norm2: bool = False,
    norm3: bool = False,
    ic: str | None = None,
    sulc: bool = False,
    sulconly: bool = False,
    a: float | None = None,
    parcellation_table: InputPathType | None = None,
    n: float | None = None,
    verbose: float | None = None,
    debug_vertex: float | None = None,
    gcs_means: str | None = None,
    gcs_priors: str | None = None,
    gcs_diff: str | None = None,
    nfill: float | None = None,
    no_fill: bool = False,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MrisCaTrainOutputs:
    """
    Creates a cortical parcellation atlas file based on one or more annotated
    subjects using probabilistic information.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        hemi: Hemisphere: rh or lh.
        canonsurf: Canonical surface filename.
        annot_file: Annotation filename.
        subjects: List of subject ids.
        output_file: Classifier array output file.
        sdir: Directory as subjects directory (default: $SUBJECTS_DIR).
        nbrs: Neighborhood size (default=2).
        orig: Filename of original surface (default=smoothwm).
        norm1: GCSA normalize input #1 after reading (default: disabled).
        norm2: GCSA normalize input #2 after reading (default: disabled).
        norm3: GCSA normalize input #3 after reading (default: disabled).
        ic: Parameters passed to the classifier routine (default: -ic 7 4).
        sulc: Specify sulc as only input (default: sulcus and curvature).
        sulconly: Same as -sulc.
        a: Number of nearest neighbor smoothing iterations to apply to input 1\
            (default=5).
        parcellation_table: Parcellation table input file (default: none).
        n: Number of inputs (default=1,max=3).
        verbose: Diagnostic level (default=0).
        debug_vertex: Debug diagnostic level for a specific vertex (default=0).
        gcs_means: Extract likelihood means for all classes for given input.
        gcs_priors: Extract priors for all classes for given input.
        gcs_diff: Determine whether GCSAs are different.
        nfill: Set the max number of iterations for filling empty vertices.
        no_fill: Do not fill at all.
        help_: Print help info.
        version: Print version info.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisCaTrainOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_CA_TRAIN_METADATA)
    cargs = []
    cargs.append("mris_ca_train")
    cargs.append(hemi)
    cargs.append(execution.input_file(canonsurf))
    cargs.append(execution.input_file(annot_file))
    cargs.extend(subjects)
    cargs.append(output_file)
    if sdir is not None:
        cargs.extend([
            "-sdir",
            sdir
        ])
    if nbrs is not None:
        cargs.extend([
            "-nbrs",
            str(nbrs)
        ])
    if orig is not None:
        cargs.extend([
            "-orig",
            execution.input_file(orig)
        ])
    if norm1:
        cargs.append("-norm1")
    if norm2:
        cargs.append("-norm2")
    if norm3:
        cargs.append("-norm3")
    if ic is not None:
        cargs.extend([
            "-ic",
            ic
        ])
    if sulc:
        cargs.append("-sulc")
    if sulconly:
        cargs.append("-sulconly")
    if a is not None:
        cargs.extend([
            "-a",
            str(a)
        ])
    if parcellation_table is not None:
        cargs.extend([
            "-t",
            execution.input_file(parcellation_table)
        ])
    if n is not None:
        cargs.extend([
            "-n",
            str(n)
        ])
    if verbose is not None:
        cargs.extend([
            "-v",
            str(verbose)
        ])
    if debug_vertex is not None:
        cargs.extend([
            "-debug-vertex",
            str(debug_vertex)
        ])
    if gcs_means is not None:
        cargs.extend([
            "-gcs-means",
            gcs_means
        ])
    if gcs_priors is not None:
        cargs.extend([
            "-gcs-priors",
            gcs_priors
        ])
    if gcs_diff is not None:
        cargs.extend([
            "-gcs-diff",
            gcs_diff
        ])
    if nfill is not None:
        cargs.extend([
            "-nfill",
            str(nfill)
        ])
    if no_fill:
        cargs.append("-no-fill")
    if help_:
        cargs.append("--help")
    if version:
        cargs.append("--version")
    ret = MrisCaTrainOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_CA_TRAIN_METADATA",
    "MrisCaTrainOutputs",
    "mris_ca_train",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_VOLUME_METADATA = Metadata(
    id="90a9e134e9f1f52b94a8a65439a8368906985f96.boutiques",
    name="mris_volume",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisVolumeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_volume(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_volume(
    surface_file: InputPathType,
    verbose_flag: bool = False,
    runner: Runner | None = None,
) -> MrisVolumeOutputs:
    """
    A tool for computing the volume of a closed surface using a divergence formula.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        surface_file: The closed surface file whose volume is to be computed.
        verbose_flag: Output more messages for verbose output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisVolumeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_VOLUME_METADATA)
    cargs = []
    cargs.append("mris_volume")
    cargs.append(execution.input_file(surface_file))
    if verbose_flag:
        cargs.append("-v")
    ret = MrisVolumeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_VOLUME_METADATA",
    "MrisVolumeOutputs",
    "mris_volume",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_ROTATE_METADATA = Metadata(
    id="ef8f8112c666b20f57f67d98677ecae66ab493de.boutiques",
    name="mris_rotate",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisRotateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_rotate(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    rotated_surface: OutputPathType
    """The rotated output surface."""


def mris_rotate(
    input_surface: InputPathType,
    alpha_deg: float,
    beta_deg: float,
    gamma_deg: float,
    output_surface: str,
    regfile: InputPathType | None = None,
    invalidate_geometry: bool = False,
    runner: Runner | None = None,
) -> MrisRotateOutputs:
    """
    Rotate a surface given three angles.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: Input surface file to be rotated.
        alpha_deg: Rotation angle in degrees around the X-axis.
        beta_deg: Rotation angle in degrees around the Y-axis.
        gamma_deg: Rotation angle in degrees around the Z-axis.
        output_surface: Output surface file after rotation.
        regfile: Extract angles from registration file, ignores alpha, beta,\
            gamma.
        invalidate_geometry: Invalidate volume geometry in output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisRotateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_ROTATE_METADATA)
    cargs = []
    cargs.append("mris_rotate")
    cargs.append(execution.input_file(input_surface))
    cargs.append(str(alpha_deg))
    cargs.append(str(beta_deg))
    cargs.append(str(gamma_deg))
    cargs.append(output_surface)
    if regfile is not None:
        cargs.extend([
            "-r",
            execution.input_file(regfile)
        ])
    if invalidate_geometry:
        cargs.append("-n")
    ret = MrisRotateOutputs(
        root=execution.output_file("."),
        rotated_surface=execution.output_file(output_surface),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_ROTATE_METADATA",
    "MrisRotateOutputs",
    "mris_rotate",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_CREATE_TESTS_METADATA = Metadata(
    id="8ce88e171c28b9dd055727016c3b5d136019a784.boutiques",
    name="mri_create_tests",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriCreateTestsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_create_tests(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_create_tests(
    input_file: InputPathType,
    out_src: str,
    out_target: str,
    input_target: InputPathType | None = None,
    lta_in: str | None = None,
    mask: InputPathType | None = None,
    noise: float | None = None,
    outlier: float | None = None,
    outlier_box: float | None = None,
    translation_flag: bool = False,
    transdist: float | None = None,
    rotation_flag: bool = False,
    maxdeg: float | None = None,
    intensity_flag: bool = False,
    iscale: float | None = None,
    lta_out: str | None = None,
    lta_outs: str | None = None,
    lta_outt: str | None = None,
    iscale_out: str | None = None,
    runner: Runner | None = None,
) -> MriCreateTestsOutputs:
    """
    Creates test cases for the registration by mapping the input to a source (half
    way backward) and to a target (half way forward).
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input volume to be modified.
        out_src: Output source volume name.
        out_target: Output target volume name.
        input_target: Input target volume to be modified, must be in the same\
            space as input volume. Default: use input volume to create output\
            target.
        lta_in: Specify LTA for mapping input to output target. Cannot be used\
            with --rotation or --translation.
        mask: Mask source MRI with mask file.
        noise: Add global Gaussian noise.
        outlier: Add random outlier voxels.
        outlier_box: Add box containing random voxels.
        translation_flag: Apply random translation.
        transdist: Set maximal translation distance in mm. Default is 11.
        rotation_flag: Apply random rotation.
        maxdeg: Maximal rotation in degrees. Default is 25.
        intensity_flag: Apply random intensity scaling.
        iscale: Use fixed intensity scaling parameter.
        lta_out: Write used random transform to LTA.
        lta_outs: Write halfway LTA for source.
        lta_outt: Write halfway LTA for target.
        iscale_out: Write used intensity scaling parameter.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriCreateTestsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_CREATE_TESTS_METADATA)
    cargs = []
    cargs.append("mri_create_tests")
    cargs.extend([
        "--in",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "--outs",
        out_src
    ])
    cargs.extend([
        "--outt",
        out_target
    ])
    if input_target is not None:
        cargs.extend([
            "--int",
            execution.input_file(input_target)
        ])
    if lta_in is not None:
        cargs.extend([
            "--lta-in",
            lta_in
        ])
    if mask is not None:
        cargs.extend([
            "--mask",
            execution.input_file(mask)
        ])
    if noise is not None:
        cargs.extend([
            "--noise",
            str(noise)
        ])
    if outlier is not None:
        cargs.extend([
            "--outlier",
            str(outlier)
        ])
    if outlier_box is not None:
        cargs.extend([
            "--outlier-box",
            str(outlier_box)
        ])
    if translation_flag:
        cargs.append("--translation")
    if transdist is not None:
        cargs.extend([
            "--transdist",
            str(transdist)
        ])
    if rotation_flag:
        cargs.append("--rotation")
    if maxdeg is not None:
        cargs.extend([
            "--maxdeg",
            str(maxdeg)
        ])
    if intensity_flag:
        cargs.append("--intensity")
    if iscale is not None:
        cargs.extend([
            "--iscale",
            str(iscale)
        ])
    if lta_out is not None:
        cargs.extend([
            "--lta-out",
            lta_out
        ])
    if lta_outs is not None:
        cargs.extend([
            "--lta-outs",
            lta_outs
        ])
    if lta_outt is not None:
        cargs.extend([
            "--lta-outt",
            lta_outt
        ])
    if iscale_out is not None:
        cargs.extend([
            "--iscale-out",
            iscale_out
        ])
    ret = MriCreateTestsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_CREATE_TESTS_METADATA",
    "MriCreateTestsOutputs",
    "mri_create_tests",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

STIMBAND_METADATA = Metadata(
    id="464e80031a1b4a970344b72621a7160776336ad8.boutiques",
    name="stimband",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class StimbandOutputs(typing.NamedTuple):
    """
    Output object returned when calling `stimband(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_band: OutputPathType
    """The frequency band covering at least 90% of the power of the stimulus
    columns."""


def stimband(
    verbose_flag: bool = False,
    min_freq: float | None = None,
    min_bwidth: float | None = None,
    min_pow: float | None = None,
    runner: Runner | None = None,
) -> StimbandOutputs:
    """
    Determines frequency band covering at least 90% of the 'power' (|FFT|^2) of
    stimulus columns from X.nocensor.xmat.1D files.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        verbose_flag: Print the power band for each individual stimulus column\
            from each matrix.
        min_freq: Set the minimum frequency output for the band. Default value\
            is 0.01.
        min_bwidth: Set the minimum bandwidth output (top frequency minus\
            bottom frequency). Default is 0.03.
        min_pow: Set the minimum power fraction (percentage) to 'ff' instead of\
            the default 90%. Value must be in the range 50..99.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `StimbandOutputs`).
    """
    if min_pow is not None and not (50 <= min_pow <= 99): 
        raise ValueError(f"'min_pow' must be between 50 <= x <= 99 but was {min_pow}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(STIMBAND_METADATA)
    cargs = []
    cargs.append("stimband")
    if verbose_flag:
        cargs.append("-verb")
    cargs.append("[MATRIXFILES...]")
    cargs.append("[ADDITIONAL_MATRIXFILES...]")
    if min_freq is not None:
        cargs.extend([
            "-min_freq",
            str(min_freq)
        ])
    if min_bwidth is not None:
        cargs.extend([
            "-min_bwidth",
            str(min_bwidth)
        ])
    if min_pow is not None:
        cargs.extend([
            "-min_pow",
            str(min_pow)
        ])
    ret = StimbandOutputs(
        root=execution.output_file("."),
        output_band=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "STIMBAND_METADATA",
    "StimbandOutputs",
    "stimband",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REG_TOOLS_METADATA = Metadata(
    id="f395b2a3b7977bc04bd46c3a00a35e8d43532b2f.boutiques",
    name="reg_tools",
    package="niftyreg",
    container_image_tag="vnmd/niftyreg_1.4.0:20220819",
)


class RegToolsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `reg_tools(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image_file: OutputPathType | None
    """File containing the output image"""


def reg_tools(
    input_image: InputPathType,
    output_image: str | None = None,
    add_value_or_image: str | None = None,
    sub_value_or_image: str | None = None,
    mul_value_or_image: str | None = None,
    div_value_or_image: str | None = None,
    smooth_value: float | None = None,
    smooth_gaussian: list[float] | None = None,
    rms_image: InputPathType | None = None,
    binarize: bool = False,
    threshold_value: float | None = None,
    nan_mask_image: InputPathType | None = None,
    runner: Runner | None = None,
) -> RegToolsOutputs:
    """
    A versatile tool for manipulating and processing medical images.
    
    Author: NiftyReg Developers
    
    URL: http://cmictig.cs.ucl.ac.uk/wiki/index.php/NiftyReg
    
    Args:
        input_image: Filename of the input image.
        output_image: Filename of the output image.
        add_value_or_image: This image (or value) is added to the input.
        sub_value_or_image: This image (or value) is subtracted from the input.
        mul_value_or_image: This image (or value) is multiplied with the input.
        div_value_or_image: This image (or value) is divided by the input.
        smooth_value: The input image is smoothed using a B-spline curve.
        smooth_gaussian: The input image is smoothed using a Gaussian kernel.
        rms_image: Compute the mean RMS between the input image and this image.
        binarize: Binarize the input image (val!=0?val=1:val=0).
        threshold_value: Threshold the input image (val<thr?val=0:val=1).
        nan_mask_image: This image is used to mask the input image. Voxels\
            outside of the mask are set to NaN.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RegToolsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REG_TOOLS_METADATA)
    cargs = []
    cargs.append("reg_tools")
    cargs.extend([
        "-in",
        execution.input_file(input_image)
    ])
    if output_image is not None:
        cargs.extend([
            "-out",
            output_image
        ])
    if add_value_or_image is not None:
        cargs.extend([
            "-add",
            add_value_or_image
        ])
    if sub_value_or_image is not None:
        cargs.extend([
            "-sub",
            sub_value_or_image
        ])
    if mul_value_or_image is not None:
        cargs.extend([
            "-mul",
            mul_value_or_image
        ])
    if div_value_or_image is not None:
        cargs.extend([
            "-div",
            div_value_or_image
        ])
    if smooth_value is not None:
        cargs.extend([
            "-smo",
            str(smooth_value)
        ])
    if smooth_gaussian is not None:
        cargs.extend([
            "-smoG",
            *map(str, smooth_gaussian)
        ])
    if rms_image is not None:
        cargs.extend([
            "-rms",
            execution.input_file(rms_image)
        ])
    if binarize:
        cargs.append("-bin")
    if threshold_value is not None:
        cargs.extend([
            "-thr",
            str(threshold_value)
        ])
    if nan_mask_image is not None:
        cargs.extend([
            "-nan",
            execution.input_file(nan_mask_image)
        ])
    ret = RegToolsOutputs(
        root=execution.output_file("."),
        output_image_file=execution.output_file(output_image) if (output_image is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REG_TOOLS_METADATA",
    "RegToolsOutputs",
    "reg_tools",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_COMPUTE_VOLUME_FRACTIONS_METADATA = Metadata(
    id="02961ba1db8b265f07c25a08461891b1caa9c54c.boutiques",
    name="mris_compute_volume_fractions",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisComputeVolumeFractionsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_compute_volume_fractions(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume_file: OutputPathType
    """The output volume file containing the computed fractions."""


def mris_compute_volume_fractions(
    volume_file: InputPathType,
    surface_file: InputPathType,
    accuracy: float,
    output_file: str,
    debug: bool = False,
    checkopts: bool = False,
    runner: Runner | None = None,
) -> MrisComputeVolumeFractionsOutputs:
    """
    Computes volume fractions based on a given surface and volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        volume_file: Input volume file.
        surface_file: Input surface file.
        accuracy: Required accuracy.
        output_file: Output volume file for the fractions.
        debug: Turn on debugging.
        checkopts: Don't run anything, just check options and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisComputeVolumeFractionsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_COMPUTE_VOLUME_FRACTIONS_METADATA)
    cargs = []
    cargs.append("mris_compute_volume_fractions")
    cargs.extend([
        "--vol",
        execution.input_file(volume_file)
    ])
    cargs.extend([
        "--surf",
        execution.input_file(surface_file)
    ])
    cargs.extend([
        "--acc",
        str(accuracy)
    ])
    cargs.extend([
        "--out",
        output_file
    ])
    if debug:
        cargs.append("--debug")
    if checkopts:
        cargs.append("--checkopts")
    ret = MrisComputeVolumeFractionsOutputs(
        root=execution.output_file("."),
        output_volume_file=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_COMPUTE_VOLUME_FRACTIONS_METADATA",
    "MrisComputeVolumeFractionsOutputs",
    "mris_compute_volume_fractions",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_LABEL_TO_BORDER_METADATA = Metadata(
    id="c9144b25b3b7d9cd115a4ceff34091bcdb41ab28.boutiques",
    name="cifti-label-to-border",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class CiftiLabelToBorderBorderOutputs(typing.NamedTuple):
    """
    Output object returned when calling `list[CiftiLabelToBorderBorder] | None(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    border_out: OutputPathType
    """the output border file"""


@dataclasses.dataclass
class CiftiLabelToBorderBorder:
    """
    specify output file for a surface structure.
    """
    surface: InputPathType
    """the surface to use for neighbor and structure information"""
    border_out: str
    """the output border file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-border")
        cargs.append(execution.input_file(self.surface))
        cargs.append(self.border_out)
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> CiftiLabelToBorderBorderOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `CiftiLabelToBorderBorderOutputs`).
        """
        ret = CiftiLabelToBorderBorderOutputs(
            root=execution.output_file("."),
            border_out=execution.output_file(self.border_out),
        )
        return ret


class CiftiLabelToBorderOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_label_to_border(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    border: list[CiftiLabelToBorderBorderOutputs] | None
    """Outputs from `CiftiLabelToBorderBorder`.This is a list of outputs with
    the same length and order as the inputs."""


def cifti_label_to_border(
    cifti_in: InputPathType,
    opt_placement_fraction: float | None = None,
    opt_column_column: str | None = None,
    border: list[CiftiLabelToBorderBorder] | None = None,
    runner: Runner | None = None,
) -> CiftiLabelToBorderOutputs:
    """
    Draw borders around cifti labels.
    
    For each surface, takes the labels on the matching structure and draws
    borders around the labels. Use -column to only draw borders around one label
    map.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_in: the input cifti dlabel file.
        opt_placement_fraction: set how far along the edge border points are\
            drawn: fraction along edge from inside vertex (default 0.33).
        opt_column_column: select a single column: the column number or name.
        border: specify output file for a surface structure.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiLabelToBorderOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_LABEL_TO_BORDER_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-label-to-border")
    cargs.append(execution.input_file(cifti_in))
    if opt_placement_fraction is not None:
        cargs.extend([
            "-placement",
            str(opt_placement_fraction)
        ])
    if opt_column_column is not None:
        cargs.extend([
            "-column",
            opt_column_column
        ])
    if border is not None:
        cargs.extend([a for c in [s.run(execution) for s in border] for a in c])
    ret = CiftiLabelToBorderOutputs(
        root=execution.output_file("."),
        border=[i.outputs(execution) if hasattr(i, "outputs") else None for i in border] if border else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_LABEL_TO_BORDER_METADATA",
    "CiftiLabelToBorderBorder",
    "CiftiLabelToBorderBorderOutputs",
    "CiftiLabelToBorderOutputs",
    "cifti_label_to_border",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_TOPO_FIXER_METADATA = Metadata(
    id="4b97f9063ba3136c5f175963808d0468021279ab.boutiques",
    name="mris_topo_fixer",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisTopoFixerOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_topo_fixer(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    fixed_surface: OutputPathType
    """Surface file with fixed topology."""


def mris_topo_fixer(
    input_surface: InputPathType,
    output_surface: str,
    runner: Runner | None = None,
) -> MrisTopoFixerOutputs:
    """
    FreeSurfer tool for fixing topological defects in cortical surface meshes.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: Input surface file that needs topological fixing.
        output_surface: Output surface file with fixed topology.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisTopoFixerOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_TOPO_FIXER_METADATA)
    cargs = []
    cargs.append("mris_topo_fixer")
    cargs.append(execution.input_file(input_surface))
    cargs.append(output_surface)
    ret = MrisTopoFixerOutputs(
        root=execution.output_file("."),
        fixed_surface=execution.output_file(output_surface),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_TOPO_FIXER_METADATA",
    "MrisTopoFixerOutputs",
    "mris_topo_fixer",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_LABEL_VALS_METADATA = Metadata(
    id="f676fd9e1e255bdfcf8e5d6db1b8b8906a5d7a0e.boutiques",
    name="mri_label_vals",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriLabelValsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_label_vals(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_label_vals(
    volume: InputPathType,
    label_file: InputPathType,
    cras_flag: bool = False,
    help_flag: bool = False,
    runner: Runner | None = None,
) -> MriLabelValsOutputs:
    """
    Extract values at label coordinates from a volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        volume: Input volume file.
        label_file: Input label file.
        cras_flag: Use this option if the label was created where c_(r,a,s) !=\
            0.
        help_flag: Print help.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriLabelValsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_LABEL_VALS_METADATA)
    cargs = []
    cargs.append("mri_label_vals")
    cargs.append(execution.input_file(volume))
    cargs.append(execution.input_file(label_file))
    if cras_flag:
        cargs.append("-cras")
    if help_flag:
        cargs.append("-u")
    ret = MriLabelValsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_LABEL_VALS_METADATA",
    "MriLabelValsOutputs",
    "mri_label_vals",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

POINTSET2LABEL_METADATA = Metadata(
    id="76bc9f6d69a026b807da7960f3bfd93ec5f85c89.boutiques",
    name="pointset2label",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Pointset2labelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `pointset2label(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_label_volume: OutputPathType
    """Output volume label file with applied labels."""


def pointset2label(
    waypoint_file: InputPathType,
    input_volume: InputPathType,
    label_value: float,
    output_volume: str,
    clear_option: bool = False,
    runner: Runner | None = None,
) -> Pointset2labelOutputs:
    """
    Tool for applying waypoint labels to a volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        waypoint_file: Path to the waypoint file.
        input_volume: Path to the input volume file.
        label_value: Label value to apply at the waypoints.
        output_volume: Path to the output volume label file.
        clear_option: Clear the input volume before processing.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Pointset2labelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(POINTSET2LABEL_METADATA)
    cargs = []
    cargs.append("pointset2label")
    cargs.append(execution.input_file(waypoint_file))
    cargs.append(execution.input_file(input_volume))
    cargs.append(str(label_value))
    cargs.append(output_volume)
    if clear_option:
        cargs.append("-clear")
    ret = Pointset2labelOutputs(
        root=execution.output_file("."),
        output_label_volume=execution.output_file(output_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "POINTSET2LABEL_METADATA",
    "Pointset2labelOutputs",
    "pointset2label",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__ADD_EDGE_METADATA = Metadata(
    id="e1c15db21c7ca3b4679541ce445b80838292b240.boutiques",
    name="@AddEdge",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VAddEdgeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__add_edge(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    dset_nn_ec: OutputPathType
    """Edge composite image of dataset with its own edges"""
    base_dset_dset_nn_ec: OutputPathType
    """Edge composite image of base dataset together with the edges of the input
    dset_nn dataset"""
    base_dset_e3: OutputPathType
    """Edge-only datasets - used in single edge display option"""
    dset_nn_e3: OutputPathType
    """Edge-only input datasets - used in single edge display option"""


def v__add_edge(
    input_files: list[InputPathType],
    examine_list: str | None = None,
    ax_mont: str | None = None,
    ax_geom: str | None = None,
    sag_geom: str | None = None,
    layout_file: str | None = None,
    no_layout: bool = False,
    edge_percentile: int | None = None,
    single_edge: bool = False,
    opacity: int | None = None,
    keep_temp: bool = False,
    no_deoblique: bool = False,
    auto_record: bool = False,
    auto: bool = False,
    no_auto: bool = False,
    runner: Runner | None = None,
) -> VAddEdgeOutputs:
    """
    A script to create composite edge-enhanced datasets and drive the AFNI interface
    to display the results.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_files: Input datasets.
        examine_list: Use list of paired datasets from file.
        ax_mont: Axial montage string (default='2x2:24').
        ax_geom: Axial image window geometry (default='777x702+433+334').
        sag_geom: Sagittal image window geometry (default='540x360+4+436').
        layout_file: Use AFNI layout file for display.
        no_layout: Do not use layout. Use AFNI as it is open.
        edge_percentile: Specify edge threshold value (default=30%).
        single_edge: Show only a single edge in composite image.
        opacity: Set opacity of overlay (default=9 opaque).
        keep_temp: Do not remove temporary files.
        no_deoblique: Do not deoblique any data to show overlap.
        auto_record: Save JPEG files of current slices without prompting.
        auto: Closes old AFNI sessions and relaunches a new one ready to listen\
            to @AddEdge in review mode.
        no_auto: Opposite of -auto.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VAddEdgeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__ADD_EDGE_METADATA)
    cargs = []
    cargs.append("@AddEdge")
    cargs.extend([execution.input_file(f) for f in input_files])
    if examine_list is not None:
        cargs.extend([
            "-examinelist",
            examine_list
        ])
    if ax_mont is not None:
        cargs.extend([
            "-ax_mont",
            ax_mont
        ])
    if ax_geom is not None:
        cargs.extend([
            "-ax_geom",
            ax_geom
        ])
    if sag_geom is not None:
        cargs.extend([
            "-sag_geom",
            sag_geom
        ])
    if layout_file is not None:
        cargs.extend([
            "-layout",
            layout_file
        ])
    if no_layout:
        cargs.append("-no_layout")
    if edge_percentile is not None:
        cargs.extend([
            "-edge_percentile",
            str(edge_percentile)
        ])
    if single_edge:
        cargs.append("-single_edge")
    if opacity is not None:
        cargs.extend([
            "-opa",
            str(opacity)
        ])
    if keep_temp:
        cargs.append("-keep_temp")
    if no_deoblique:
        cargs.append("-no_deoblique")
    if auto_record:
        cargs.append("-auto_record")
    if auto:
        cargs.append("-auto")
    if no_auto:
        cargs.append("-no_auto")
    ret = VAddEdgeOutputs(
        root=execution.output_file("."),
        dset_nn_ec=execution.output_file("dset_nn_ec"),
        base_dset_dset_nn_ec=execution.output_file("base_dset_dset_nn_ec"),
        base_dset_e3=execution.output_file("base_dset_e3"),
        dset_nn_e3=execution.output_file("dset_nn_e3"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VAddEdgeOutputs",
    "V__ADD_EDGE_METADATA",
    "v__add_edge",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_MODIFY_METADATA = Metadata(
    id="358c84f244977ad8d56905af20cc90fb0f1f3919.boutiques",
    name="mri_modify",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriModifyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_modify(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_modify(
    x_ras: list[float],
    y_ras: list[float],
    z_ras: list[float],
    cras: list[float],
    x_size: float,
    y_size: float,
    z_size: float,
    tr: float,
    te: float,
    ti: float,
    fa: float,
    xform: str,
    input_volume: InputPathType,
    output_volume: str,
    runner: Runner | None = None,
) -> MriModifyOutputs:
    """
    Tool for modifying MRI image headers.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        x_ras: X direction cosines (xr, xa, xs).
        y_ras: Y direction cosines (yr, ya, ys).
        z_ras: Z direction cosines (zr, za, zs).
        cras: Center RAS coordinates (cr, ca, cs).
        x_size: Size of voxel in X dimension.
        y_size: Size of voxel in Y dimension.
        z_size: Size of voxel in Z dimension.
        tr: Repetition time (TR).
        te: Echo time (TE).
        ti: Inversion time (TI).
        fa: Flip angle (degrees).
        xform: New transformation file name.
        input_volume: Input volume.
        output_volume: Output volume.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriModifyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_MODIFY_METADATA)
    cargs = []
    cargs.append("mri_modify")
    cargs.extend([
        "-xras",
        *map(str, x_ras)
    ])
    cargs.extend([
        "-yras",
        *map(str, y_ras)
    ])
    cargs.extend([
        "-zras",
        *map(str, z_ras)
    ])
    cargs.extend([
        "-cras",
        *map(str, cras)
    ])
    cargs.extend([
        "-xsize",
        str(x_size)
    ])
    cargs.extend([
        "-ysize",
        str(y_size)
    ])
    cargs.extend([
        "-zsize",
        str(z_size)
    ])
    cargs.extend([
        "-tr",
        str(tr)
    ])
    cargs.extend([
        "-te",
        str(te)
    ])
    cargs.extend([
        "-ti",
        str(ti)
    ])
    cargs.extend([
        "-fa",
        str(fa)
    ])
    cargs.extend([
        "-xform",
        xform
    ])
    cargs.append(execution.input_file(input_volume))
    cargs.append(output_volume)
    ret = MriModifyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_MODIFY_METADATA",
    "MriModifyOutputs",
    "mri_modify",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_MERGE_PARCELLATIONS_METADATA = Metadata(
    id="59eb13227975afaa7a05e9947ae25c61de64b8ec.boutiques",
    name="mris_merge_parcellations",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisMergeParcellationsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_merge_parcellations(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_merge_parcellations(
    surface: InputPathType,
    label1: InputPathType,
    label2: InputPathType,
    annot_name: str | None = None,
    runner: Runner | None = None,
) -> MrisMergeParcellationsOutputs:
    """
    This program computes the Hausdorff distance between two labels on the surface.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        surface: Surface file to analyze.
        label1: First label file.
        label2: Second label file.
        annot_name: Compute pairwise Hausdorff distance between all annotations.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisMergeParcellationsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_MERGE_PARCELLATIONS_METADATA)
    cargs = []
    cargs.append("mris_merge_parcellations")
    cargs.append(execution.input_file(surface))
    cargs.append(execution.input_file(label1))
    cargs.append(execution.input_file(label2))
    if annot_name is not None:
        cargs.extend([
            "-a",
            annot_name
        ])
    ret = MrisMergeParcellationsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_MERGE_PARCELLATIONS_METADATA",
    "MrisMergeParcellationsOutputs",
    "mris_merge_parcellations",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REG_ALADIN_METADATA = Metadata(
    id="0cdcd5294ca36b2c6f5e68cc4ee34d2019bd8f9f.boutiques",
    name="reg_aladin",
    package="niftyreg",
    container_image_tag="vnmd/niftyreg_1.4.0:20220819",
)


class RegAladinOutputs(typing.NamedTuple):
    """
    Output object returned when calling `reg_aladin(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_affine_file: OutputPathType
    """File containing the output affine transformation"""


def reg_aladin(
    reference_image: InputPathType,
    floating_image: InputPathType,
    symmetric: bool = False,
    output_affine: str | None = None,
    rigid_only: bool = False,
    direct_affine: bool = False,
    smooth_ref: float | None = None,
    smooth_float: float | None = None,
    num_levels: float | None = None,
    first_levels: float | None = None,
    use_nifti_origin: bool = False,
    percent_block: float | None = None,
    percent_inlier: float | None = None,
    runner: Runner | None = None,
) -> RegAladinOutputs:
    """
    Block Matching algorithm for global registration based on "Reconstructing a 3D
    structure from serial histological sections", Image and Vision Computing, 2001.
    
    Author: NiftyReg Developers
    
    URL: http://cmictig.cs.ucl.ac.uk/wiki/index.php/NiftyReg
    
    Args:
        reference_image: Filename of the reference (target) image.
        floating_image: Filename of the floating (source) image.
        symmetric: Uses symmetric version of the algorithm.
        output_affine: Filename which contains the output affine transformation.
        rigid_only: To perform a rigid registration only.
        direct_affine: Directly optimize 12 DoF affine.
        smooth_ref: Smooth the reference image using the specified sigma (mm).
        smooth_float: Smooth the floating image using the specified sigma (mm).
        num_levels: Number of levels to perform.
        first_levels: Only perform the first levels.
        use_nifti_origin: Use the NIFTI header origins to initialize the\
            translation.
        percent_block: Percentage of block to use.
        percent_inlier: Percentage of inlier for the LTS.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RegAladinOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REG_ALADIN_METADATA)
    cargs = []
    cargs.append("reg_aladin")
    cargs.extend([
        "-ref",
        execution.input_file(reference_image)
    ])
    cargs.extend([
        "-flo",
        execution.input_file(floating_image)
    ])
    if symmetric:
        cargs.append("-sym")
    if output_affine is not None:
        cargs.extend([
            "-aff",
            output_affine
        ])
    if rigid_only:
        cargs.append("-rigOnly")
    if direct_affine:
        cargs.append("-affDirect")
    if smooth_ref is not None:
        cargs.extend([
            "-smooR",
            str(smooth_ref)
        ])
    if smooth_float is not None:
        cargs.extend([
            "-smooF",
            str(smooth_float)
        ])
    if num_levels is not None:
        cargs.extend([
            "-ln",
            str(num_levels)
        ])
    if first_levels is not None:
        cargs.extend([
            "-lp",
            str(first_levels)
        ])
    if use_nifti_origin:
        cargs.append("-nac")
    if percent_block is not None:
        cargs.extend([
            "-%v",
            str(percent_block)
        ])
    if percent_inlier is not None:
        cargs.extend([
            "-%i",
            str(percent_inlier)
        ])
    ret = RegAladinOutputs(
        root=execution.output_file("."),
        output_affine_file=execution.output_file("outputAffine.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REG_ALADIN_METADATA",
    "RegAladinOutputs",
    "reg_aladin",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_FIX_TOPOLOGY_METADATA = Metadata(
    id="5d7620635b54b49eefdf920890334e0223158089.boutiques",
    name="mris_fix_topology",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisFixTopologyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_fix_topology(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_fix_topology(
    subject_name: str,
    hemisphere: str,
    orig_name: str | None = "orig.nofix",
    sphere_name: str | None = "qsphere.nofix",
    inflated_name: str | None = "inflated.nofix",
    output_name: str | None = "orig",
    defect_base_name: str | None = "defect",
    write_fixed_inflated: bool = False,
    verbose: bool = False,
    verbose_low: bool = False,
    warnings_: bool = False,
    errors: bool = False,
    movies: bool = False,
    intersect: bool = False,
    mappings: bool = False,
    correct_defect: float | None = None,
    niters: float | None = None,
    genetic: bool = False,
    optimize: bool = False,
    random_: float | None = None,
    seed: float | None = None,
    diag: bool = False,
    mgz: bool = False,
    smooth: float | None = None,
    diagnostic_level: float | None = None,
    threads: float | None = None,
    runner: Runner | None = None,
) -> MrisFixTopologyOutputs:
    """
    Computes a mapping from the unit sphere onto the cortical surface, ensuring a
    topologically correct surface.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_name: Subject name.
        hemisphere: Hemisphere.
        orig_name: Input orig name (default is orig.nofix).
        sphere_name: Sphere name (default is qsphere.nofix).
        inflated_name: Inflated name (default is inflated.nofix).
        output_name: Output name (default is orig).
        defect_base_name: Defect basename (default is defect).
        write_fixed_inflated: Write fixed inflated.
        verbose: Increase verbosity.
        verbose_low: Low verbosity.
        warnings_: Show warnings.
        errors: Show errors.
        movies: Generate movies.
        intersect: Check if the final surface self-intersects.
        mappings: Generate several different mappings.
        correct_defect: Correct specific defect number.
        niters: Number of iterations for genetic algorithm.
        genetic: Use genetic search.
        optimize: Optimize genetic search.
        random_: Use random search with specified iterations.
        seed: Set random number generator seed.
        diag: Sets DIAG_SAVE_DIAGS.
        mgz: Assume volumes are in mgz format.
        smooth: Smooth corrected surface by N iterations.
        diagnostic_level: Set diagnostic level.
        threads: Set number of OpenMP threads.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisFixTopologyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_FIX_TOPOLOGY_METADATA)
    cargs = []
    cargs.append("mris_fix_topology")
    cargs.append(subject_name)
    cargs.append(hemisphere)
    if orig_name is not None:
        cargs.extend([
            "-orig",
            orig_name
        ])
    if sphere_name is not None:
        cargs.extend([
            "-sphere",
            sphere_name
        ])
    if inflated_name is not None:
        cargs.extend([
            "-inflated",
            inflated_name
        ])
    if output_name is not None:
        cargs.extend([
            "-out",
            output_name
        ])
    if defect_base_name is not None:
        cargs.extend([
            "-defect",
            defect_base_name
        ])
    if write_fixed_inflated:
        cargs.append("-wi")
    if verbose:
        cargs.append("-verbose")
    if verbose_low:
        cargs.append("-verbose_low")
    if warnings_:
        cargs.append("-warnings")
    if errors:
        cargs.append("-errors")
    if movies:
        cargs.append("-movies")
    if intersect:
        cargs.append("-intersect")
    if mappings:
        cargs.append("-mappings")
    if correct_defect is not None:
        cargs.extend([
            "-correct_defect",
            str(correct_defect)
        ])
    if niters is not None:
        cargs.extend([
            "-niters",
            str(niters)
        ])
    if genetic:
        cargs.append("-genetic")
    if optimize:
        cargs.append("-optimize")
    if random_ is not None:
        cargs.extend([
            "-random",
            str(random_)
        ])
    if seed is not None:
        cargs.extend([
            "-seed",
            str(seed)
        ])
    if diag:
        cargs.append("-diag")
    if mgz:
        cargs.append("-mgz")
    if smooth is not None:
        cargs.extend([
            "-s",
            str(smooth)
        ])
    if diagnostic_level is not None:
        cargs.extend([
            "-v",
            str(diagnostic_level)
        ])
    if threads is not None:
        cargs.extend([
            "-threads",
            str(threads)
        ])
    ret = MrisFixTopologyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_FIX_TOPOLOGY_METADATA",
    "MrisFixTopologyOutputs",
    "mris_fix_topology",
]
